@@ -1,4 +1,4 @@
-/* Copyright (c) 2014 The Chromium OS Authors. All rights reserved.
+/* Copyright 2014 The ChromiumOS Authors
  * Use of this source code is governed by a BSD-style license that can be
  * found in the LICENSE file.
  *
@@ -9,6 +9,7 @@
 #include "2common.h"
 #include "2rsa.h"
 
+test_mockable
 vb2_error_t vb2_safe_memcmp(const void *s1, const void *s2, size_t size)
 {
 	const unsigned char *us1 = s1;
@@ -147,6 +148,7 @@ vb2_error_t vb2_verify_member_inside(const void *parent, size_t parent_size,
 	return VB2_SUCCESS;
 }
 
+test_mockable
 vb2_error_t vb2_verify_digest(const struct vb2_public_key *key,
 			      struct vb2_signature *sig, const uint8_t *digest,
 			      const struct vb2_workbuf *wb)
@@ -154,6 +156,9 @@ vb2_error_t vb2_verify_digest(const struct vb2_public_key *key,
 	/* A signature is destroyed in the process of being verified. */
 	uint8_t *sig_data = vb2_signature_data_mutable(sig);
 
+	if (!sig->data_size)
+		return VB2_ERROR_VDATA_NOT_ENOUGH_DATA;
+
 	if (sig->sig_size != vb2_rsa_sig_size(key->sig_alg)) {
 		VB2_DEBUG("Wrong data signature size for algorithm, "
 			  "sig_size=%d, expected %d for algorithm %d.\n",
@@ -182,6 +187,7 @@ vb2_error_t vb2_verify_digest(const struct vb2_public_key *key,
 	return vb2_rsa_verify_digest(key, sig_data, digest, wb);
 }
 
+test_mockable
 vb2_error_t vb2_verify_data(const uint8_t *data, uint32_t size,
 			    struct vb2_signature *sig,
 			    const struct vb2_public_key *key,
