@@ -1,4 +1,4 @@
-/* Copyright (c) 2014 The Chromium OS Authors. All rights reserved.
+/* Copyright 2014 The ChromiumOS Authors
  * Use of this source code is governed by a BSD-style license that can be
  * found in the LICENSE file.
  */
@@ -29,7 +29,7 @@ enum vb2_return_code {
 	 */
 	VB2_REQUEST = 0x1000,
 
-	/* Calling firmware requested shutdown via VbExIsShutdownRequested() */
+	/* Calling firmware requested shutdown */
 	VB2_REQUEST_SHUTDOWN = 0x1001,
 
 	/* Calling firmware needs to perform a reboot */
@@ -713,6 +713,9 @@ enum vb2_return_code {
 	/* Enabling developer mode is not allowed in non-recovery mode */
 	VB2_ERROR_API_ENABLE_DEV_NOT_ALLOWED,
 
+	/* Failed to select next slot in vb2_select_fw_slot() */
+	VB2_ERROR_API_NEXT_SLOT_UNAVAILABLE,
+
 	/**********************************************************************
 	 * Errors which may be generated by implementations of vb2ex functions.
 	 * Implementation may also return its own specific errors, which should
@@ -754,29 +757,32 @@ enum vb2_return_code {
 	 * Deprecated: functionality removed with legacy UI (b/167643628) */
 	VB2_ERROR_DEPRECATED_EX_SET_VENDOR_DATA,
 
-	/* The memory test is running but the output buffer was unchanged. */
-	VB2_ERROR_EX_DIAG_TEST_RUNNING,
+	/* The memory test is running but the output buffer was unchanged.
+	   Deprecated with b/172339016. */
+	VB2_ERROR_DEPRECATED_EX_DIAG_TEST_RUNNING,
 
-	/* The memory test is running and the output buffer was updated. */
-	VB2_ERROR_EX_DIAG_TEST_UPDATED,
+	/* The memory test is running and the output buffer was updated.
+	   Deprecated with b/172339016. */
+	VB2_ERROR_DEPRECATED_EX_DIAG_TEST_UPDATED,
 
-	/* The memory test initialization failed. */
-	VB2_ERROR_EX_DIAG_TEST_INIT_FAILED,
+	/* The memory test initialization failed.
+	   Deprecated with b/172339016. */
+	VB2_ERROR_DEPRECATED_EX_DIAG_TEST_INIT_FAILED,
 
 	/**********************************************************************
-	 * LoadKernel errors
+	 * Kernel loading errors
 	 *
 	 * Should be ordered by specificity -- lower number means more specific.
 	 */
 	VB2_ERROR_LK = 0x100b0000,
 
-	/* Only an invalid kernel was found in LoadKernel() */
+	/* Only an invalid kernel was found in vb2api_load_kernel() */
 	VB2_ERROR_LK_INVALID_KERNEL_FOUND = 0x100b1000,
 
-	/* No kernel partitions were found in LoadKernel() */
+	/* No kernel partitions were found in vb2api_load_kernel() */
 	VB2_ERROR_LK_NO_KERNEL_FOUND = 0x100b2000,
 
-	/* No working block devices were found in VbTryLoadKernel() */
+	/* No working block devices were found */
 	VB2_ERROR_LK_NO_DISK_FOUND = 0x100b3000,
 
 	/**********************************************************************
@@ -843,6 +849,9 @@ enum vb2_return_code {
 	/* Flashrom exited with failure status */
 	VB2_ERROR_FLASHROM,
 
+	/* cbfstool exited with failure status */
+	VB2_ERROR_CBFSTOOL,
+
 	/**********************************************************************
 	 * Errors generated by host library key functions
 	 */
