@@ -13,3 +13,13 @@
 pub mod crossystem {
     include!(concat!(env!("OUT_DIR"), "/crossystem.rs"));
 }
+
+#[allow(
+    clippy::all,
+    non_camel_case_types,
+    non_snake_case,
+    non_upper_case_globals
+)]
+pub mod vboot_host {
+    include!(concat!(env!("OUT_DIR"), "/vboot_host.rs"));
+}
