@@ -1,5 +1,5 @@
 #!/bin/bash
-# Copyright 2018 The Chromium OS Authors. All rights reserved.
+# Copyright 2018 The ChromiumOS Authors
 # Use of this source code is governed by a BSD-style license that can be
 # found in the LICENSE file.
 
@@ -25,7 +25,7 @@ set -u
 
 PRE_PVT_BID_FLAG=0x10
 MP_BID_FLAG=0x10000
-CR50_NODE_LOCKED_VERSION="0.5.12"
+NIGHTLY_BID_FLAG=0x20000
 
 # Convert unsigned 32 bit value into a signed one.
 to_int32() {
@@ -144,29 +144,32 @@ paste_bin() {
   dd if="${blob}" of="${file}" seek="${offset}" bs=1 conv=notrunc
 }
 
-# This function accepts one argument, the name of the GSC manifest file which
-# needs to be verified and in certain cases altered.
+# This function accepts two arguments, the name of the GSC manifest file which
+# needs to be verified and in certain cases altered and the generation of the
+# chip (h or g).
 #
 # The function verifies that the input manifest is a proper json file, and
-# that the manifest conforms to GSC version numbering and board ID flags
-# conventions for various build images:
-#
-# - only binaries where version is set to CR50_NODE_LOCKED_VERSION can be
-#   converted to node locked images. Board IDs for node locked images come
-#   from signing instructions, and the config1 manifest field value must have
-#   the 0x80000000 bit set.
+# that the manifest conforms to GSC board ID flags conventions for various
+# build images:
+
+# - board IDs for node locked images come from signing instructions, and the
+#   config1 manifest field value must have the 0x80000000 bit set.
 #
 # - when signing pre-pvt binaries (major version number is even) the 0x10
 #   flags bit must be set.
 #
 # - when signing mp images (major version number is odd), the 0x10000 flags
 #   bit must be set (this can be overridden by signing instructions).
+#
+# - when signing nightly images (major version number is 26), the flags are
+#   0x20000
 verify_and_prepare_gsc_manifest() {
-  if [[ $# -ne 1 ]]; then
-    die "Usage: verify_and_prepare_gsc_manifest <manifest .json file>"
+  if [[ $# -ne 2 ]]; then
+    die "Usage: verify_and_prepare_gsc_manifest <manifest .json file> <generation>"
   fi
 
   local manifest_json="$1"
+  local generation="$2"
 
   local bid_flags
   local config1
@@ -194,15 +197,21 @@ verify_and_prepare_gsc_manifest() {
 
   case "${INSN_TARGET:-}" in
 
+    (Nightly)
+      # At this point Nightly builds must have the major version 26 and
+      # 0x20000 board id flags, so it can't run on released devices.
+      if (( (major == 26 ) && (bid_flags == NIGHTLY_BID_FLAG) )); then
+        # The Nightly target is only valid for ti50 devices.
+        if [[ "${generation}" == "d" ]] ; then
+          return 0
+        fi
+      fi
+      ;;
+
     (NodeLocked)
       if [[ -z ${INSN_DEVICE_ID:-} ]]; then
         die "Node locked target without Device ID value"
       fi
-      # Case of a node locked image, it must have the fixed version.
-      if [[ "${epoch}.${major}.${minor}" != "${CR50_NODE_LOCKED_VERSION}" ]]
-      then
-        die "Won't create node locked images for version $epoch.$major.$minor"
-      fi
 
       local sub
       local devid0
@@ -248,11 +257,13 @@ verify_and_prepare_gsc_manifest() {
       ;;
 
     (*)
-      die "Unsupported target '${INSN_TARGET:-}'"
+      die "Unsupported target '${INSN_TARGET:-}': " \
+	  "generation = '${generation}' major = '${major}'"
   esac
 
-  die "Inconsistent manifest ${manifest_json}: major = '${major}'," \
-      "board_id_flags = '${bid_flags}' target = '${INSN_TARGET}'"
+  die "Inconsistent manifest ${manifest_json}: generation = '${generation}'," \
+      "major = '${major}',board_id_flags = '${bid_flags}' " \
+      "target = '${INSN_TARGET}'"
 }
 
 # This function accepts two arguments, names of two binary files.
@@ -347,6 +358,7 @@ sign_rw() {
   local rma_key_base=""
   local signer_command_params
   local temp_dir
+  local prohibited_blobs=()
 
   temp_dir="$(make_temp_dir)"
   signer_command_params=(-x "${fuses_file}" --key "${key_file}")
@@ -382,6 +394,12 @@ sign_rw() {
       # Indicate D1 signing.
       signer_command_params+=( "--dauntless" "--ihex" )
       base_name="ti50"
+      # Key and hashes used in dev, must not leak into prod signed images.
+      prohibited_blobs=(
+        "${rma_key_dir}/rma_test_pub_key.bin"
+        "${rma_key_dir}/arv_2k_test_key_hash.bin"
+        "${rma_key_dir}/arv_4k_test_key_hash.bin"
+      )
       ;;
     (*)
       die "Unknown generation value \"${generation}\""
@@ -399,6 +417,7 @@ sign_rw() {
     local hex_signed="${temp_dir}/hex_signed"
     local bin_signed="${temp_dir}/bin_signed"
     local hex_base
+    local blob
 
     # Make sure output files are not owned by root.
     touch "${bin_signed}" "${hex_signed}"
@@ -422,6 +441,15 @@ sign_rw() {
       fi
     fi
 
+    for blob in "${prohibited_blobs[@]}"; do
+      if [[ ! -f ${blob} ]]; then
+        die "${blob} not found in the GSC tarball"
+      fi
+      if find_blob_in_blob "${bin_signed}" "${blob}"; then
+        die "${blob} found in signed image"
+      fi
+    done
+
     hex_base="$(get_hex_base "${hex_signed}")"
     paste_bin "${result_file}" "${bin_signed}" "${image_base}" "${hex_base}"
   done
@@ -513,7 +541,7 @@ sign_gsc_firmware() {
       ;;
   esac
 
-  verify_and_prepare_gsc_manifest "${manifest_file}"
+  verify_and_prepare_gsc_manifest "${manifest_file}" "${generation}"
 
   dd if=/dev/zero bs="${IMAGE_SIZE}" count=1 status=none |
     tr '\000' '\377' > "${output_file}"
