@@ -1,4 +1,4 @@
-/* Copyright (c) 2011 The Chromium OS Authors. All rights reserved.
+/* Copyright 2011 The ChromiumOS Authors
  * Use of this source code is governed by a BSD-style license that can be
  * found in the LICENSE file.
  */
@@ -11,7 +11,7 @@
 #include <stdlib.h>
 
 #include "host_common.h"
-#include "test_common.h"
+#include "common/tests.h"
 #include "tlcl.h"
 #include "tlcl_tests.h"
 
