@@ -14,17 +14,12 @@
 
 unsigned int get_cpu_speed(void);
 
-void arch_ndelay(uint64_t n);
-
 /**
  * Delay for a specified number of nanoseconds.
  *
  * @param ns Number of nanoseconds to delay for.
  */
-static inline void ndelay(unsigned int ns)
-{
-	arch_ndelay((uint64_t)ns);
-}
+void ndelay(uint64_t n);
 
 /**
  * Delay for a specified number of microseconds.
@@ -33,7 +28,7 @@ static inline void ndelay(unsigned int ns)
  */
 static inline void udelay(unsigned int us)
 {
-	arch_ndelay((uint64_t)us * NSECS_PER_USEC);
+	ndelay((uint64_t)us * NSECS_PER_USEC);
 }
 
 /**
@@ -43,7 +38,7 @@ static inline void udelay(unsigned int us)
  */
 static inline void mdelay(unsigned int ms)
 {
-	arch_ndelay((uint64_t)ms * NSECS_PER_MSEC);
+	ndelay((uint64_t)ms * NSECS_PER_MSEC);
 }
 
 /**
@@ -53,7 +48,7 @@ static inline void mdelay(unsigned int ms)
  */
 static inline void delay(unsigned int s)
 {
-	arch_ndelay((uint64_t)s * NSECS_PER_SEC);
+	ndelay((uint64_t)s * NSECS_PER_SEC);
 }
 
 #endif /* LIBPAYLOAD_DELAY_H */
