@@ -35,50 +35,6 @@
 #include <limits.h>
 #include <errno.h>
 
-/**
- * Calculate the length of a fixed-size string.
- *
- * @param str The input string.
- * @param maxlen Return at most maxlen characters as length of the string.
- * @return The length of the string, not including the final NUL character.
- * 	   The maximum length returned is maxlen.
- */
-size_t strnlen(const char *str, size_t maxlen)
-{
-	size_t len = 0;
-
-	/* NULL and empty strings have length 0. */
-	if (!str)
-		return 0;
-
-	/* Loop until we find a NUL character, or maxlen is reached. */
-	while ((*str++ != '\0') && (len < maxlen))
-		len++;
-
-	return len;
-}
-
-/**
- * Calculate the length of a string.
- *
- * @param str The input string.
- * @return The length of the string, not including the final NUL character.
- */
-size_t strlen(const char *str)
-{
-	size_t len = 0;
-
-	/* NULL and empty strings have length 0. */
-	if (!str)
-		return 0;
-
-	/* Loop until we find a NUL character. */
-	while (*str++ != '\0')
-		len++;
-
-	return len;
-}
-
 /**
  * Compare two strings.
  *
@@ -196,46 +152,6 @@ char *strcpy(char *d, const char *s)
 	return strncpy(d, s, strlen(s) + 1);
 }
 
-/**
- * Concatenates two strings
- *
- * @param d The destination string.
- * @param s The source string.
- * @return A pointer to the destination string.
- */
-char *strcat(char *d, const char *s)
-{
-	char *p = d + strlen(d);
-	size_t sl = strlen(s);
-
-	for (size_t i = 0; i < sl; i++)
-		p[i] = s[i];
-
-	p[sl] = '\0';
-	return d;
-}
-
-/**
- * Concatenates two strings with a maximum length.
- *
- * @param d The destination string.
- * @param s The source string.
- * @param n Not more than n characters from s will be appended to d.
- * @return A pointer to the destination string.
- */
-char *strncat(char *d, const char *s, size_t n)
-{
-	char *p = d + strlen(d);
-	size_t sl = strlen(s);
-	size_t max = n > sl ? sl : n;
-
-	for (size_t i = 0; i < max; i++)
-		p[i] = s[i];
-
-	p[max] = '\0';
-	return d;
-}
-
 /**
  * Concatenates two strings with a maximum length.
  *
@@ -321,6 +237,25 @@ char *strdup(const char *s)
 	return p;
 }
 
+/**
+ * Duplicate a string with a max length of size
+ *
+ * @param s The string to duplicate.
+ * @param size The max length of the string
+ * @return A pointer to the copy of the original string.
+ */
+char *strndup(const char *s, size_t size)
+{
+	size_t n = strnlen(s, size);
+	char *p = malloc(n + 1);
+
+	if (p != NULL) {
+		strncpy(p, s, n);
+		p[n] = 0;
+	}
+	return p;
+}
+
 /**
  * Find a substring within a string.
  *
