@@ -2,14 +2,14 @@
 
 /* Microcode update for Intel PIII and later CPUs */
 
-#include <stdint.h>
-#include <stddef.h>
 #include <cbfs.h>
-#include <arch/cpu.h>
 #include <console/console.h>
-#include <cpu/x86/msr.h>
+#include <cpu/cpu.h>
 #include <cpu/intel/microcode.h>
+#include <cpu/x86/msr.h>
 #include <smp/spinlock.h>
+#include <stdio.h>
+#include <types.h>
 
 DECLARE_SPIN_LOCK(microcode_lock)
 
@@ -171,10 +171,6 @@ static const void *find_cbfs_microcode(void)
 	msr_t msr;
 	struct cpuinfo_x86 c;
 
-	ucode_updates = cbfs_map(MICROCODE_CBFS_FILE, &microcode_len);
-	if (ucode_updates == NULL)
-		return NULL;
-
 	rev = read_microcode_rev();
 	eax = cpuid_eax(1);
 	get_fms(&c, eax);
@@ -189,6 +185,16 @@ static const void *find_cbfs_microcode(void)
 	printk(BIOS_DEBUG, "microcode: sig=0x%x pf=0x%x revision=0x%x\n",
 			sig, pf, rev);
 
+	if (CONFIG(CPU_INTEL_MICROCODE_CBFS_SPLIT_BINS)) {
+		char cbfs_filename[25];
+		snprintf(cbfs_filename, sizeof(cbfs_filename), "cpu_microcode_%x.bin", sig);
+		ucode_updates = cbfs_map(cbfs_filename, &microcode_len);
+	} else {
+		ucode_updates = cbfs_map(MICROCODE_CBFS_FILE, &microcode_len);
+	}
+	if (ucode_updates == NULL)
+		return NULL;
+
 	while (microcode_len >= sizeof(*ucode_updates)) {
 		/* Newer microcode updates include a size field, whereas older
 		 * containers set it at 0 and are exactly 2048 bytes long */
@@ -235,6 +241,12 @@ const void *intel_microcode_find(void)
 	static bool microcode_checked;
 	static const void *ucode_update;
 
+	if (ENV_CACHE_AS_RAM) {
+		printk(BIOS_ERR, "Microcode Error: Early microcode patching is not supported due"
+				"to NEM limitation\n");
+		return NULL;
+	}
+
 	if (microcode_checked)
 		return ucode_update;
 
