@@ -365,12 +365,14 @@ static atomic_t *load_sipi_vector(struct mp_params *mp_params)
 	ap_count = &sp->ap_count;
 	atomic_set(ap_count, 0);
 
-	/* Make sure SIPI data hits RAM so the APs that come up will see the
-	   startup code even if the caches are disabled. */
-	if (clflush_supported())
-		clflush_region((uintptr_t)mod_loc, module_size);
-	else
-		wbinvd();
+	if (!self_snooping_supported()) {
+		/* Make sure SIPI data hits RAM so the APs that come up will see the
+		   startup code even if the caches are disabled. */
+		if (clflush_supported())
+			clflush_region((uintptr_t)mod_loc, module_size);
+		else
+			wbinvd();
+	}
 
 	return ap_count;
 }
@@ -434,7 +436,7 @@ static enum cb_err send_sipi_to_aps(int ap_count, atomic_t *num_aps, int sipi_ve
 		printk(BIOS_DEBUG, "done.\n");
 	}
 
-	lapic_send_ipi_others(LAPIC_INT_ASSERT | LAPIC_DM_STARTUP | sipi_vector);
+	lapic_send_ipi_others(LAPIC_INT_ASSERT | LAPIC_MT_STARTUP | sipi_vector);
 	printk(BIOS_DEBUG, "Waiting for SIPI to complete...\n");
 	if (apic_wait_timeout(10000 /* 10 ms */, 50 /* us */) != CB_SUCCESS) {
 		printk(BIOS_ERR, "timed out.\n");
@@ -474,7 +476,7 @@ static enum cb_err start_aps(struct bus *cpu_bus, int ap_count, atomic_t *num_ap
 	}
 
 	/* Send INIT IPI to all but self. */
-	lapic_send_ipi_others(LAPIC_INT_ASSERT | LAPIC_DM_INIT);
+	lapic_send_ipi_others(LAPIC_INT_ASSERT | LAPIC_MT_INIT);
 
 	if (!CONFIG(X86_INIT_NEED_1_SIPI)) {
 		printk(BIOS_DEBUG, "Waiting for 10ms after sending INIT.\n");
@@ -658,7 +660,7 @@ void smm_initiate_relocation_parallel(void)
 		printk(BIOS_DEBUG, "done.\n");
 	}
 
-	lapic_send_ipi_self(LAPIC_INT_ASSERT | LAPIC_DM_SMI);
+	lapic_send_ipi_self(LAPIC_INT_ASSERT | LAPIC_MT_SMI);
 
 	if (lapic_busy()) {
 		if (apic_wait_timeout(1000 /* 1 ms */, 100 /* us */) != CB_SUCCESS) {
@@ -826,8 +828,10 @@ static void load_smm_handlers(void)
 		smm_disable();
 	}
 
-	/* Ensure the SMM handlers hit DRAM before performing first SMI. */
-	wbinvd();
+	if (!self_snooping_supported()) {
+		/* Ensure the SMM handlers hit DRAM before performing first SMI. */
+		wbinvd();
+	}
 
 	/*
 	 * Indicate that the SMM handlers have been loaded and MP
