@@ -32,11 +32,10 @@
  *     IBM Corporation - initial implementation
  *****************************************************************************/
 
+#include <boot/coreboot_tables.h>
+#include <framebuffer_info.h>
 #include <string.h>
 #include <types.h>
-#if IS_ENABLED(CONFIG_FRAMEBUFFER_SET_VESA_MODE)
-#include <boot/coreboot_tables.h>
-#endif
 
 #include <endian.h>
 
@@ -52,13 +51,22 @@
 #include "interrupt.h"
 #include "device.h"
 
-#include <cbfs.h>
-
 #include <delay.h>
-#include "../../src/lib/jpeg.h"
 
 #include <vbe.h>
 
+// these structs only store a subset of the VBE defined fields
+// only those needed.
+typedef struct {
+	char signature[4];
+	u16 version;
+	u8 *oem_string_ptr;
+	u32 capabilities;
+	u16 video_mode_list[256];	// lets hope we never have more than
+					// 256 video modes...
+	u16 total_memory;
+} vbe_info_t;
+
 // pointer to VBEInfoBuffer, set by vbe_prepare
 u8 *vbe_info_buffer = 0;
 
@@ -66,7 +74,7 @@ u8 *vbe_info_buffer = 0;
 u8 *biosmem;
 u32 biosmem_size;
 
-#if IS_ENABLED(CONFIG_FRAMEBUFFER_SET_VESA_MODE)
+#if CONFIG(FRAMEBUFFER_SET_VESA_MODE)
 static inline u8
 vbe_prepare(void)
 {
@@ -75,14 +83,14 @@ vbe_prepare(void)
 	memset(vbe_info_buffer, 0, 512);
 	//set VbeSignature to "VBE2" to indicate VBE 2.0+ request
 	vbe_info_buffer[0] = 'V';
-	vbe_info_buffer[0] = 'B';
-	vbe_info_buffer[0] = 'E';
-	vbe_info_buffer[0] = '2';
+	vbe_info_buffer[1] = 'B';
+	vbe_info_buffer[2] = 'E';
+	vbe_info_buffer[3] = '2';
 	// ES:DI store pointer to buffer in virtual mem see vbe_info_buffer above...
 	M.x86.R_EDI = 0x0;
 	M.x86.R_ES = VBE_SEGMENT;
 
-	return 0;		// successfull init
+	return 0;		// successful init
 }
 
 // VBE Function 00h
@@ -156,11 +164,6 @@ vbe_info(vbe_info_t * info)
 
 static int mode_info_valid;
 
-static int vbe_mode_info_valid(void)
-{
-	return mode_info_valid;
-}
-
 // VBE Function 01h
 static u8
 vbe_get_mode_info(vbe_mode_info_t * mode_info)
@@ -321,7 +324,7 @@ vbe_set_color(u16 color_number, u32 color_value)
 }
 
 static u8
-vbe_get_color(u16 color_number, u32 * color_value)
+vbe_get_color(u16 color_number, u32 *color_value)
 {
 	vbe_prepare();
 	// call VBE function 09h (Set/Get Palette Data Function)
@@ -502,7 +505,7 @@ vbe_get_info(void)
 	vbe_get_ddc_info(&ddc_info);
 
 #if 0
-	DEBUG_PRINTF_VBE("DDC: edid_tranfer_time: %d\n",
+	DEBUG_PRINTF_VBE("DDC: edid_transfer_time: %d\n",
 			 ddc_info.edid_transfer_time);
 	DEBUG_PRINTF_VBE("DDC: ddc_level: %x\n", ddc_info.ddc_level);
 	DEBUG_PRINTF_VBE("DDC: EDID:\n");
@@ -705,7 +708,14 @@ vbe_get_info(void)
 }
 #endif
 
-vbe_mode_info_t mode_info;
+static vbe_mode_info_t mode_info;
+
+const vbe_mode_info_t *vbe_mode_info(void)
+{
+	if (!mode_info_valid || !mode_info.vesa.phys_base_ptr)
+		return NULL;
+	return &mode_info;
+}
 
 void vbe_set_graphics(void)
 {
@@ -734,60 +744,24 @@ void vbe_set_graphics(void)
 	vbe_get_mode_info(&mode_info);
 	vbe_set_mode(&mode_info);
 
-#if IS_ENABLED(CONFIG_BOOTSPLASH)
-	unsigned char *framebuffer =
-		(unsigned char *) le32_to_cpu(mode_info.vesa.phys_base_ptr);
-	DEBUG_PRINTF_VBE("FRAMEBUFFER: 0x%p\n", framebuffer);
+	const struct lb_framebuffer fb = {
+		.physical_address    = mode_info.vesa.phys_base_ptr,
+		.x_resolution        = le16_to_cpu(mode_info.vesa.x_resolution),
+		.y_resolution        = le16_to_cpu(mode_info.vesa.y_resolution),
+		.bytes_per_line      = le16_to_cpu(mode_info.vesa.bytes_per_scanline),
+		.bits_per_pixel      = mode_info.vesa.bits_per_pixel,
+		.red_mask_pos        = mode_info.vesa.red_mask_pos,
+		.red_mask_size       = mode_info.vesa.red_mask_size,
+		.green_mask_pos      = mode_info.vesa.green_mask_pos,
+		.green_mask_size     = mode_info.vesa.green_mask_size,
+		.blue_mask_pos       = mode_info.vesa.blue_mask_pos,
+		.blue_mask_size      = mode_info.vesa.blue_mask_size,
+		.reserved_mask_pos   = mode_info.vesa.reserved_mask_pos,
+		.reserved_mask_size  = mode_info.vesa.reserved_mask_size,
+		.orientation         = LB_FB_ORIENTATION_NORMAL,
+	};
 
-	struct jpeg_decdata *decdata;
-
-	/* Switching Intel IGD to 1MB video memory will break this. Who
-	 * cares. */
-	// int imagesize = 1024*768*2;
-
-	unsigned char *jpeg = cbfs_boot_map_with_leak("bootsplash.jpg",
-							CBFS_TYPE_BOOTSPLASH,
-							NULL);
-	if (!jpeg) {
-		DEBUG_PRINTF_VBE("Could not find bootsplash.jpg\n");
-		return;
-	}
-	DEBUG_PRINTF_VBE("Splash at %p ...\n", jpeg);
-	dump(jpeg, 64);
-
-	decdata = malloc(sizeof(*decdata));
-	int ret = 0;
-	DEBUG_PRINTF_VBE("Decompressing boot splash screen...\n");
-	ret = jpeg_decode(jpeg, framebuffer, 1024, 768, 16, decdata);
-	DEBUG_PRINTF_VBE("returns %x\n", ret);
-#endif
-}
-
-int fill_lb_framebuffer(struct lb_framebuffer *framebuffer)
-{
-	if (!vbe_mode_info_valid())
-		return -1;
-
-	framebuffer->physical_address = le32_to_cpu(mode_info.vesa.phys_base_ptr);
-
-	framebuffer->x_resolution = le16_to_cpu(mode_info.vesa.x_resolution);
-	framebuffer->y_resolution = le16_to_cpu(mode_info.vesa.y_resolution);
-	framebuffer->bytes_per_line = le16_to_cpu(mode_info.vesa.bytes_per_scanline);
-	framebuffer->bits_per_pixel = mode_info.vesa.bits_per_pixel;
-
-	framebuffer->red_mask_pos = mode_info.vesa.red_mask_pos;
-	framebuffer->red_mask_size = mode_info.vesa.red_mask_size;
-
-	framebuffer->green_mask_pos = mode_info.vesa.green_mask_pos;
-	framebuffer->green_mask_size = mode_info.vesa.green_mask_size;
-
-	framebuffer->blue_mask_pos = mode_info.vesa.blue_mask_pos;
-	framebuffer->blue_mask_size = mode_info.vesa.blue_mask_size;
-
-	framebuffer->reserved_mask_pos = mode_info.vesa.reserved_mask_pos;
-	framebuffer->reserved_mask_size = mode_info.vesa.reserved_mask_size;
-
-	return 0;
+	fb_add_framebuffer_info_ex(&fb);
 }
 
 void vbe_textmode_console(void)
