@@ -367,7 +367,9 @@ void ast_post_gpu(struct drm_device *dev)
 	ast_enable_mmio(dev);
 	ast_set_def_ext_reg(dev);
 
-	if (ast->config_mode == ast_use_p2a) {
+	if (ast->chip == AST2600) {
+		return;
+	} else if (ast->config_mode == ast_use_p2a) {
 		if (ast->chip == AST2500)
 			ast_post_chip_2500(dev);
 		else if (ast->chip == AST2300 || ast->chip == AST2400)
@@ -740,9 +742,9 @@ static void finetuneDQSI(struct ast_private *ast)
 					passcnt[dqsip]++;
 					tag[dqsip][dlli] = 'P';
 					if (dlli < pass[dqidly][dqsip][0])
-						pass[dqidly][dqsip][0] = (u16) dlli;
+						pass[dqidly][dqsip][0] = (u16)dlli;
 					if (dlli > pass[dqidly][dqsip][1])
-						pass[dqidly][dqsip][1] = (u16) dlli;
+						pass[dqidly][dqsip][1] = (u16)dlli;
 				} else if (passcnt[dqsip] >= 5)
 					break;
 				else {
