@@ -1,6 +1,7 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
 #include <console/console.h>
+#include <device/device.h>
 #include <device/i2c_bus.h>
 #include <types.h>
 #include <bootstate.h>
@@ -63,7 +64,7 @@ static int ptn3460_write_edid(struct device *dev, u8 edid_num, u8 *data)
 static void ptn3460_init(struct device *dev)
 {
 	struct ptn_3460_config cfg;
-	uint8_t edid_data[PTN_EDID_LEN], edid_tab, *ptr = (uint8_t *) &cfg;
+	uint8_t edid_data[PTN_EDID_LEN], edid_tab, *ptr = (uint8_t *)&cfg;
 	int i, val;
 
 	/* Guard against re-initialization of the device */
@@ -75,13 +76,13 @@ static void ptn3460_init(struct device *dev)
 	}
 
 	/* Mainboard provides EDID data. */
-	if (mb_get_edid(edid_data) != CB_SUCCESS) {
+	if (mainboard_ptn3460_get_edid(edid_data) != CB_SUCCESS) {
 		printk(BIOS_ERR, "PTN3460 error: Unable to get EDID data from mainboard.\n");
 		return;
 	}
 
 	/* Mainboard decides which EDID table has to be used. */
-	edid_tab = mb_select_edid_table();
+	edid_tab = mainboard_ptn3460_select_edid_table();
 	if (edid_tab > PTN_MAX_EDID_NUM) {
 		printk(BIOS_ERR, "PTN3460 error: invalid EDID table (%d) selected.\n",
 		       edid_tab);
@@ -107,8 +108,8 @@ static void ptn3460_init(struct device *dev)
 	}
 	/* Mainboard can modify the configuration data.
 	   Write back configuration data to PTN3460 if modified by mainboard */
-	if (mb_adjust_cfg(&cfg) == PTN_CFG_MODIFIED) {
-		ptr = (uint8_t *) &cfg;
+	if (mainboard_ptn3460_config(&cfg) == CB_SUCCESS) {
+		ptr = (uint8_t *)&cfg;
 		for (i = 0; i < sizeof(struct ptn_3460_config); i++) {
 			val = i2c_dev_writeb_at(dev, PTN_CONFIG_OFF + i, *ptr++);
 			if (val < 0) {
@@ -122,17 +123,17 @@ static void ptn3460_init(struct device *dev)
 	init_done = true;
 }
 
-__weak enum cb_err mb_get_edid(uint8_t edid_data[0x80])
+__weak enum cb_err mainboard_ptn3460_get_edid(uint8_t edid_data[PTN_EDID_LEN])
 {
 	return CB_ERR;
 }
-__weak uint8_t mb_select_edid_table(void)
+__weak uint8_t mainboard_ptn3460_select_edid_table(void)
 {
 	return 0;
 }
-__weak int mb_adjust_cfg(struct ptn_3460_config *cfg_ptr)
+__weak enum cb_err mainboard_ptn3460_config(struct ptn_3460_config *cfg_ptr)
 {
-	return 0;
+	return CB_ERR;
 }
 
 static struct device_operations ptn3460_ops = {
@@ -147,7 +148,7 @@ static void ptn3460_enable(struct device *dev)
 }
 
 struct chip_operations drivers_i2c_ptn3460_ops = {
-	CHIP_NAME("PTN3460")
+	.name = "PTN3460",
 	.enable_dev = ptn3460_enable
 };
 
@@ -170,7 +171,9 @@ static void ptn3460_early_init(void *unused)
 		printk(BIOS_ERR, "Failed to find the PTN3460 device!\n");
 		return;
 	}
-
+	/* Initialize the I2C controller before it is used. */
+	if (ptn_dev->upstream && ptn_dev->upstream->dev->ops && ptn_dev->upstream->dev->ops->init)
+		ptn_dev->upstream->dev->ops->init(ptn_dev->upstream->dev);
 	ptn3460_init(ptn_dev);
 }
 
