@@ -3,7 +3,7 @@
 #ifndef DRIVERS_PC80_TPM_CHIP_H
 #define DRIVERS_PC80_TPM_CHIP_H
 
-typedef struct drivers_pc80_tpm_config {
+struct drivers_pc80_tpm_config {
 	/*
 	 * TPM Interrupt polarity:
 	 *
@@ -13,6 +13,6 @@ typedef struct drivers_pc80_tpm_config {
 	 *  Falling Edge  3
 	 */
 	u8 irq_polarity;
-} tpm_config_t;
+};
 
 #endif /* DRIVERS_PC80_TPM_CHIP_H */
