@@ -5,6 +5,8 @@
 
 #include <acpi/acpi_device.h>
 
+#define MAX_GENERIC_PROPERTY_LIST 10
+
 struct drivers_spi_acpi_config {
 	const char *hid;		/* ACPI _HID (required) */
 	const char *cid;		/* ACPI _CID */
@@ -19,9 +21,6 @@ struct drivers_spi_acpi_config {
 	/* Use GPIO based interrupt instead of PIRQ */
 	struct acpi_gpio irq_gpio;
 
-	/* Disable reset and enable GPIO export in _CRS */
-	bool disable_gpio_export_in_crs;
-
 	/* Does the device have a power resource? */
 	bool has_power_resource;
 
@@ -45,6 +44,9 @@ struct drivers_spi_acpi_config {
 	unsigned int stop_delay_ms;
 	/* Delay to be inserted after enabling stop. */
 	unsigned int stop_off_delay_ms;
+	/* Generic properties for exporting device-specific data to the OS */
+	struct acpi_dp property_list[MAX_GENERIC_PROPERTY_LIST];
+	unsigned int property_count;
 };
 
 #endif /* __SPI_ACPI_CHIP_H__ */
