@@ -2,7 +2,7 @@
 /* This is a driver for a SPI interfaced TPM2 device.
  *
  * It assumes that the required SPI interface has been initialized before the
- * driver is started. A 'sruct spi_slave' pointer passed at initialization is
+ * driver is started. A 'struct spi_slave' pointer passed at initialization is
  * used to direct traffic to the correct SPI interface. This driver does not
  * provide a way to instantiate multiple TPM devices. Also, to keep things
  * simple, the driver unconditionally uses of TPM locality zero.
@@ -134,7 +134,7 @@ static enum cb_err start_transaction(int read_write, size_t bytes, unsigned int
 	 * flow control (Section "6.4.5 Flow Control").
 	 *
 	 * Again, the slave (TPM device) expects each transaction to start
-	 * with a 4 byte header trasmitted by master. The header indicates if
+	 * with a 4 byte header transmitted by master. The header indicates if
 	 * the master needs to read or write a register, and the register
 	 * address.
 	 *
@@ -231,7 +231,7 @@ static void trace_dump(const char *prefix, uint32_t reg,
 
 		/*
 		 * Data read from or written to FIFO or not in 4 byte
-		 * quantiites is printed byte at a time.
+		 * quantities is printed byte at a time.
 		 */
 		for (i = 0; i < bytes; i++) {
 			if (current_char &&
@@ -333,7 +333,7 @@ static uint8_t tpm2_read_access_reg(void)
 static void tpm2_write_access_reg(uint8_t cmd)
 {
 	/* Writes to access register can set only 1 bit at a time. */
-	assert (!(cmd & (cmd - 1)));
+	assert(!(cmd & (cmd - 1)));
 
 	tpm2_write_reg(TPM_ACCESS_REG, &cmd, sizeof(cmd));
 }
@@ -391,10 +391,11 @@ static enum cb_err tpm2_claim_locality(void)
 static const uint32_t supported_did_vids[] = {
 	0x00281ae0,  /* H1 based Cr50 security chip. */
 	0x504a6666,  /* H1D3C based Ti50 security chip. */
+	0x50666666,  /* OpenTitan based Ti50 security chip. */
 	0x0000104a   /* ST33HTPH2E32 */
 };
 
-int tpm2_init(struct spi_slave *spi_if)
+tpm_result_t tpm2_init(struct spi_slave *spi_if)
 {
 	uint32_t did_vid, status, intf_id;
 	uint8_t cmd;
@@ -433,7 +434,7 @@ int tpm2_init(struct spi_slave *spi_if)
 	if (!retries) {
 		printk(BIOS_ERR, "\n%s: Failed to connect to the TPM\n",
 		       __func__);
-		return -1;
+		return TPM_CB_FAIL;
 	}
 
 	printk(BIOS_INFO, " done!\n");
@@ -444,11 +445,11 @@ int tpm2_init(struct spi_slave *spi_if)
 		if (tpm2_read_reg(TPM_INTF_ID_REG, &intf_id, sizeof(intf_id)) != CB_SUCCESS) {
 			printk(BIOS_ERR, "\n%s: Failed to read interface ID register\n",
 			       __func__);
-			return -1;
+			return TPM_CB_FAIL;
 		}
 		if ((be32toh(intf_id) & 0xF) == 0xF) {
 			printk(BIOS_DEBUG, "\n%s: Not a TPM2 device\n", __func__);
-			return -1;
+			return TPM_CB_FAIL;
 		}
 	}
 
@@ -459,16 +460,16 @@ int tpm2_init(struct spi_slave *spi_if)
 		 * initialization after reset.
 		 */
 		if (tpm2_claim_locality() != CB_SUCCESS)
-			return -1;
+			return TPM_CB_FAIL;
 
 	if (read_tpm_sts(&status) != CB_SUCCESS) {
 		printk(BIOS_ERR, "Reading status reg failed\n");
-		return -1;
+		return TPM_CB_FAIL;
 	}
 	if ((status & TPM_STS_FAMILY_MASK) != TPM_STS_FAMILY_TPM_2_0) {
 		printk(BIOS_ERR, "unexpected TPM family value, status: %#x\n",
 		       status);
-		return -1;
+		return TPM_CB_FAIL;
 	}
 
 	/*
@@ -492,7 +493,7 @@ int tpm2_init(struct spi_slave *spi_if)
                         cr50_set_board_cfg();
 		}
 	}
-	return 0;
+	return TPM_SUCCESS;
 }
 
 /*
@@ -509,7 +510,7 @@ static enum cb_err wait_for_status(uint32_t status_mask, uint32_t status_expecte
 	do {
 		udelay(1000);
 		if (stopwatch_expired(&sw)) {
-			printk(BIOS_ERR, "failed to get expected status %x\n",
+			printk(BIOS_ERR, "failed to get expected status %#x\n",
 			       status_expected);
 			return CB_ERR;
 		}
@@ -697,7 +698,7 @@ size_t tpm2_process_command(const void *tpm2_command, size_t command_size,
 	if (debug_level_)
 		printk(BIOS_DEBUG, "\n");
 
-	/* Verify that 'data available' is not asseretd any more. */
+	/* Verify that 'data available' is not asserted any more. */
 	read_tpm_sts(&status);
 	if ((status & expected_status_bits) != TPM_STS_VALID) {
 		printk(BIOS_ERR, "unexpected final status %#x\n", status);
