@@ -53,7 +53,7 @@ static inline struct ehci_debug_info *dbgp_ehci_info(void)
 {
 	if (glob_dbg_info_p == NULL) {
 		struct ehci_debug_info *info;
-		if (ENV_BOOTBLOCK || ENV_SEPARATE_VERSTAGE || ENV_ROMSTAGE) {
+		if (ENV_BOOTBLOCK || ENV_SEPARATE_VERSTAGE || ENV_SEPARATE_ROMSTAGE) {
 			/* The message likely does not show if we hit this. */
 			if (sizeof(*info) > _car_ehci_dbg_info_size)
 				die("BUG: Increase ehci_dbg_info reserve in CAR");
@@ -730,7 +730,7 @@ void usbdebug_init(void)
 	 * from CBMEM.
 	 */
 	if (CONFIG(USBDEBUG_IN_PRE_RAM)
-	    && (ENV_ROMSTAGE || ENV_BOOTBLOCK))
+	    && (ENV_SEPARATE_ROMSTAGE || ENV_BOOTBLOCK))
 		usbdebug_hw_init(false);
 
 	/* USB console init is done early in ramstage if it was
