@@ -1,6 +1,7 @@
 /* SPDX-License-Identifier: GPL-2.0-or-later */
 
 #include <acpi/acpigen.h>
+#include <stdio.h>
 
 #include "chip.h"
 
@@ -24,9 +25,14 @@ static void conn_fill_ssdt(const struct device *dev)
 
 	acpigen_write_name_integer("_ADR", dev->path.generic.id);
 
-	if (config && config->mode_switch) {
+	if (config) {
 		struct acpi_dp *dsd = acpi_dp_new_table("_DSD");
-		acpi_dp_add_integer(dsd, "mode-switch", 1);
+
+		if (config->mode_switch)
+			acpi_dp_add_integer(dsd, "mode-switch", 1);
+		if (config->retimer_switch)
+			acpi_dp_add_integer(dsd, "retimer-switch", 1);
+
 		acpi_dp_write(dsd);
 	}
 
@@ -47,6 +53,6 @@ static void conn_enable(struct device *dev)
 }
 
 struct chip_operations ec_google_chromeec_mux_conn_ops = {
-	CHIP_NAME("CrosEC Type C Mux device")
+	.name = "CrosEC Type C Mux device",
 	.enable_dev	= conn_enable,
 };
