@@ -5,8 +5,9 @@
 
 #include <cbmem.h>
 #include <commonlib/bsd/cbfs_mdata.h>
-#include <commonlib/cbfs.h>
 #include <commonlib/mem_pool.h>
+#include <commonlib/region.h>
+#include <endian.h>
 #include <program_loading.h>
 #include <types.h>
 #include <vb2_sha.h>
@@ -54,6 +55,11 @@
  *	section), even when running in an RW stage from one of the RW CBFSs. Only relevant if
  *	CONFIG(VBOOT) is set.
  *
+ * ..._unverified_area_...: Will look for the CBFS file in the named FMAP area, rather than
+ *	any of the default (RO or RW) CBFSs. Files accessed this way are *not* verified in any
+ *	way (even if CONFIG(CBFS_VERIFICATION) is enabled) and should always be treated as
+ *	untrusted (potentially malicious) data. Mutually exclusive with the ..._ro_... variant.
+ *
  * ..._type_...: May pass in an extra enum cbfs_type *type parameter. If the value it points to
  *	is CBFS_TYPE_QUERY, it will be replaced with the actual CBFS type of the found file. If
  *	it is anything else, the type will be compared with the actually found type, and the
@@ -75,11 +81,15 @@ static inline size_t cbfs_type_load(const char *name, void *buf, size_t size,
 				    enum cbfs_type *type);
 static inline size_t cbfs_ro_type_load(const char *name, void *buf, size_t size,
 				    enum cbfs_type *type);
+static inline size_t cbfs_unverified_area_load(const char *area, const char *name,
+					       void *buf, size_t size);
 
 static inline void *cbfs_map(const char *name, size_t *size_out);
 static inline void *cbfs_ro_map(const char *name, size_t *size_out);
 static inline void *cbfs_type_map(const char *name, size_t *size_out, enum cbfs_type *type);
 static inline void *cbfs_ro_type_map(const char *name, size_t *size_out, enum cbfs_type *type);
+static inline void *cbfs_unverified_area_map(const char *area, const char *name,
+					      size_t *size_out);
 
 static inline void *cbfs_alloc(const char *name, cbfs_allocator_t allocator, void *arg,
 			       size_t *size_out);
@@ -89,6 +99,9 @@ static inline void *cbfs_type_alloc(const char *name, cbfs_allocator_t allocator
 				    size_t *size_out, enum cbfs_type *type);
 static inline void *cbfs_ro_type_alloc(const char *name, cbfs_allocator_t allocator, void *arg,
 				       size_t *size_out, enum cbfs_type *type);
+static inline void *cbfs_unverified_area_alloc(const char *area, const char *name,
+						cbfs_allocator_t allocator, void *arg,
+						size_t *size_out);
 
 static inline void *cbfs_cbmem_alloc(const char *name, uint32_t cbmem_id, size_t *size_out);
 static inline void *cbfs_ro_cbmem_alloc(const char *name, uint32_t cbmem_id, size_t *size_out);
@@ -96,6 +109,8 @@ static inline void *cbfs_type_cbmem_alloc(const char *name, uint32_t cbmem_id, s
 					  enum cbfs_type *type);
 static inline void *cbfs_ro_type_cbmem_alloc(const char *name, uint32_t cbmem_id,
 					     size_t *size_out, enum cbfs_type *type);
+static inline void *cbfs_unverified_area_cbmem_alloc(const char *area, const char *name,
+						      uint32_t cbmem_id, size_t *size_out);
 
 /*
  * Starts the processes of preloading a file into RAM.
@@ -117,7 +132,21 @@ void cbfs_preload(const char *name);
 void cbfs_unmap(void *mapping);
 
 /* Load stage into memory filling in prog. Return 0 on success. < 0 on error. */
-int cbfs_prog_stage_load(struct prog *prog);
+enum cb_err cbfs_prog_stage_load(struct prog *prog);
+
+/* Returns the size of a CBFS file, or 0 on error. Avoid using this function to allocate space,
+   and instead use cbfs_alloc() so the file only needs to be looked up once. */
+static inline size_t cbfs_get_size(const char *name);
+static inline size_t cbfs_ro_get_size(const char *name);
+
+/* Returns the type of a CBFS file, or CBFS_TYPE_NULL on error. Use cbfs_type_load() instead of
+   this where possible to avoid looking up the file more than once. */
+static inline enum cbfs_type cbfs_get_type(const char *name);
+static inline enum cbfs_type cbfs_ro_get_type(const char *name);
+
+/* Check whether a CBFS file exists. */
+static inline bool cbfs_file_exists(const char *name);
+static inline bool cbfs_ro_file_exists(const char *name);
 
 
 /**********************************************************************************************
@@ -156,26 +185,22 @@ const struct cbfs_boot_device *cbfs_get_boot_device(bool force_ro);
  * hash was still verified. Should be called once per *boot* (not once per stage) before the
  * first CBFS access.
  */
-cb_err_t cbfs_init_boot_device(const struct cbfs_boot_device *cbd,
-			       struct vb2_hash *metadata_hash);
+enum cb_err cbfs_init_boot_device(const struct cbfs_boot_device *cbd,
+				  struct vb2_hash *metadata_hash);
 
 
-/**********************************************************************************************
- *                         LEGACY APIs, TO BE DEPRECATED/REPLACED                             *
- **********************************************************************************************/
-
-/* Locate file by name and optional type. Return 0 on success. < 0 on error. */
-int cbfs_boot_locate(struct cbfsf *fh, const char *name, uint32_t *type);
-/* Locate file in a specific region of fmap. Return 0 on success. < 0 on error*/
-int cbfs_locate_file_in_region(struct cbfsf *fh, const char *region_name,
-		const char *name, uint32_t *type);
-
 /**********************************************************************************************
  *                         INTERNAL HELPERS FOR INLINES, DO NOT USE.                          *
  **********************************************************************************************/
+enum cb_err _cbfs_boot_lookup(const char *name, bool force_ro,
+			      union cbfs_mdata *mdata, struct region_device *rdev);
+
 void *_cbfs_alloc(const char *name, cbfs_allocator_t allocator, void *arg,
 		  size_t *size_out, bool force_ro, enum cbfs_type *type);
 
+void *_cbfs_unverified_area_alloc(const char *area, const char *name,
+				  cbfs_allocator_t allocator, void *arg, size_t *size_out);
+
 struct _cbfs_default_allocator_arg {
 	void *buf;
 	size_t buf_size;
@@ -211,6 +236,13 @@ static inline void *cbfs_ro_type_alloc(const char *name, cbfs_allocator_t alloca
 	return _cbfs_alloc(name, allocator, arg, size_out, true, type);
 }
 
+static inline void *cbfs_unverified_area_alloc(const char *area, const char *name,
+					       cbfs_allocator_t allocator, void *arg,
+					       size_t *size_out)
+{
+	return _cbfs_unverified_area_alloc(area, name, allocator, arg, size_out);
+}
+
 static inline void *cbfs_map(const char *name, size_t *size_out)
 {
 	return cbfs_type_map(name, size_out, NULL);
@@ -231,6 +263,12 @@ static inline void *cbfs_ro_type_map(const char *name, size_t *size_out, enum cb
 	return cbfs_ro_type_alloc(name, NULL, NULL, size_out, type);
 }
 
+static inline void *cbfs_unverified_area_map(const char *area, const char *name,
+					     size_t *size_out)
+{
+	return _cbfs_unverified_area_alloc(area, name, NULL, NULL, size_out);
+}
+
 static inline size_t _cbfs_load(const char *name, void *buf, size_t size, bool force_ro,
 				enum cbfs_type *type)
 {
@@ -263,6 +301,16 @@ static inline size_t cbfs_ro_type_load(const char *name, void *buf, size_t size,
 	return _cbfs_load(name, buf, size, true, type);
 }
 
+static inline size_t cbfs_unverified_area_load(const char *area, const char *name,
+					       void *buf, size_t size)
+{
+	struct _cbfs_default_allocator_arg arg = { .buf = buf, .buf_size = size };
+	if (_cbfs_unverified_area_alloc(area, name, _cbfs_default_allocator, &arg, &size))
+		return size;
+	else
+		return 0;
+}
+
 static inline void *cbfs_cbmem_alloc(const char *name, uint32_t cbmem_id, size_t *size_out)
 {
 	return cbfs_type_cbmem_alloc(name, cbmem_id, size_out, NULL);
@@ -287,4 +335,65 @@ static inline void *cbfs_ro_type_cbmem_alloc(const char *name, uint32_t cbmem_id
 				  size_out, type);
 }
 
+static inline void *cbfs_unverified_area_cbmem_alloc(const char *area, const char *name,
+						     uint32_t cbmem_id, size_t *size_out)
+{
+	return _cbfs_unverified_area_alloc(area, name, _cbfs_cbmem_allocator,
+					   (void *)(uintptr_t)cbmem_id, size_out);
+}
+
+static inline size_t cbfs_get_size(const char *name)
+{
+	union cbfs_mdata mdata;
+	struct region_device rdev;
+	if (_cbfs_boot_lookup(name, false, &mdata, &rdev) != CB_SUCCESS)
+		return 0;
+	return be32toh(mdata.h.len);
+}
+
+static inline size_t cbfs_ro_get_size(const char *name)
+{
+	union cbfs_mdata mdata;
+	struct region_device rdev;
+	if (_cbfs_boot_lookup(name, true, &mdata, &rdev) != CB_SUCCESS)
+		return 0;
+	return be32toh(mdata.h.len);
+}
+
+static inline enum cbfs_type cbfs_get_type(const char *name)
+{
+	union cbfs_mdata mdata;
+	struct region_device rdev;
+	if (_cbfs_boot_lookup(name, false, &mdata, &rdev) != CB_SUCCESS)
+		return CBFS_TYPE_NULL;
+	return be32toh(mdata.h.type);
+}
+
+static inline enum cbfs_type cbfs_ro_get_type(const char *name)
+{
+	union cbfs_mdata mdata;
+	struct region_device rdev;
+	if (_cbfs_boot_lookup(name, true, &mdata, &rdev) != CB_SUCCESS)
+		return CBFS_TYPE_NULL;
+	return be32toh(mdata.h.type);
+}
+
+static inline bool cbfs_file_exists(const char *name)
+{
+	union cbfs_mdata mdata;
+	struct region_device rdev;
+	if (_cbfs_boot_lookup(name, false, &mdata, &rdev) != CB_SUCCESS)
+		return false;
+	return true;
+}
+
+static inline bool cbfs_ro_file_exists(const char *name)
+{
+	union cbfs_mdata mdata;
+	struct region_device rdev;
+	if (_cbfs_boot_lookup(name, true, &mdata, &rdev) != CB_SUCCESS)
+		return false;
+	return true;
+}
+
 #endif
