@@ -57,6 +57,7 @@
 #define CPUID_SAPPHIRERAPIDS_SP_E3	0x806f6
 #define CPUID_SAPPHIRERAPIDS_SP_E4	0x806f7
 #define CPUID_SAPPHIRERAPIDS_SP_Ex	0x806f8
+#define CPUID_EMERALDRAPIDS		0xC06F2
 #define CPUID_GRANITERAPIDS		0xA06D0
 #define CPUID_SIERRAFOREST		0xA06F0
 #define CPUID_ELKHARTLAKE_A0		0x90660
@@ -84,7 +85,10 @@
 #define CPUID_RAPTORLAKE_Q0		0xb06a3
 #define CPUID_LUNARLAKE_A0_1		0xb06d0
 #define CPUID_LUNARLAKE_A0_2		0xb06d1
+#define CPUID_ARROWLAKE_H_A0		0xc0652
 #define CPUID_PANTHERLAKE_A0		0xc06c0
+#define CPUID_PANTHERLAKE_B0_1		0xc06c1
+#define CPUID_PANTHERLAKE_B0_2		0xc06c2
 #define CPUID_SNOWRIDGE_A0		0x80660
 #define CPUID_SNOWRIDGE_A1		0x80661
 #define CPUID_SNOWRIDGE_A2		0x80662
@@ -92,5 +96,6 @@
 #define CPUID_SNOWRIDGE_B0		0x80664
 #define CPUID_SNOWRIDGE_B1		0x80665
 #define CPUID_SNOWRIDGE_C0		0x80667
+#define CPUID_WILDCATLAKE_A0		0xd0650
 
 #endif /* CPU_INTEL_CPU_IDS_H */
