@@ -12,6 +12,14 @@
 #define SPI_OPCODE_WREN 0x06
 #define SPI_OPCODE_FAST_READ 0x0b
 
+/* SPI RPMC field lengths in bytes */
+#define SPI_RPMC_TAG_LEN		12
+#define SPI_RPMC_SIG_LEN		32
+#define SPI_RPMC_ROOT_KEY_LEN		32
+#define SPI_RPMC_TRUNCTAED_SIG_LEN	28 /* only used in write RPMC root key command */
+#define SPI_RPMC_KEY_DATA_LEN		4
+#define SPI_RPMC_COUNTER_DATA_LEN	4
+
 struct spi_flash;
 
 /*
@@ -49,6 +57,17 @@ struct spi_flash_ops {
 	int (*status)(const struct spi_flash *flash, u8 *reg);
 };
 
+struct spi_flash_bpbits {
+	unsigned int bp;   /*< block protection select bits */
+	bool cmp;          /*< complement protect */
+	bool tb;           /*< top=0 / bottom=1 select */
+	union {
+		struct {
+			bool srp1, srp0;
+		} winbond;
+	};
+};
+
 /* Current code assumes all callbacks are supplied in this object. */
 struct spi_flash_protection_ops {
 	/*
@@ -80,6 +99,14 @@ struct spi_flash_protection_ops {
 
 struct spi_flash_part_id;
 
+struct spi_flash_rpmc_cap {
+	bool rpmc_available;
+	bool poll_op2_ext_stat;
+	unsigned int number_of_counters;
+	uint8_t op1_write_cmd;
+	uint8_t op2_read_cmd;
+};
+
 struct spi_flash {
 	struct spi_slave spi;
 	u8 vendor;
@@ -103,6 +130,7 @@ struct spi_flash {
 	/* If !NULL all protection callbacks exist. */
 	const struct spi_flash_protection_ops *prot_ops;
 	const struct spi_flash_part_id *part;
+	struct spi_flash_rpmc_cap rpmc_caps;
 };
 
 void lb_spi_flash(struct lb_header *header);
@@ -234,4 +262,55 @@ int spi_flash_vector_helper(const struct spi_slave *slave,
  */
 uint32_t spi_flash_get_mmap_windows(struct flash_mmap_window *table);
 
+/* Print the SFDP headers read from the SPI flash */
+void spi_flash_print_sfdp_headers(const struct spi_flash *flash);
+
+/*
+ * Write RPMC root key
+ *
+ * root_key: pointer to 32 bytes long buffer with root key
+ * truncated_signature: pointer to 28 bytes long buffer with truncated signature
+ *
+ * The buffers have the bytes in the order in which they will be sent to the SPI flash
+ */
+enum cb_err spi_flash_rpmc_write_root_key(const struct spi_flash *flash, uint8_t counter_addr,
+					  const uint8_t *root_key,
+					  const uint8_t *truncated_signature);
+
+/*
+ * Update HMAC key
+ *
+ * key_data: pointer to 4 bytes long buffer with key data
+ * signature: pointer to 32 bytes long buffer with signature
+ *
+ * The buffers have the bytes in the order in which they will be sent to the SPI flash
+ */
+enum cb_err spi_flash_rpmc_update_hmac_key(const struct spi_flash *flash, uint8_t counter_addr,
+					   uint8_t *key_data, const uint8_t *signature);
+
+/*
+ * Increment monotonic counter
+ *
+ * counter_data: pointer to 4 bytes long buffer with counter data
+ * signature: pointer to 32 bytes long buffer with signature
+ *
+ * The buffers have the bytes in the order in which they will be sent to the SPI flash
+ */
+enum cb_err spi_flash_rpmc_increment(const struct spi_flash *flash, uint8_t counter_addr,
+				     const uint8_t *counter_data, const uint8_t *signature);
+
+/*
+ * Request monotonic counter
+ *
+ * tag: pointer to 12 bytes long buffer with tag
+ * signature: pointer to 32 bytes long buffer with signature
+ * counter_data: pointer to 4 bytes long buffer with counter data
+ * signature_out: pointer to 32 bytes long buffer with signature
+ *
+ * The buffers have the bytes in the order in which they will be sent to the SPI flash
+ */
+enum cb_err spi_flash_rpmc_request(const struct spi_flash *flash, uint8_t counter_addr,
+				   const uint8_t *tag, const uint8_t *signature,
+				   uint8_t *counter_data, uint8_t *signature_out);
+
 #endif /* _SPI_FLASH_H_ */
