@@ -1,7 +1,9 @@
+/* SPDX-License-Identifier: GPL-2.0-only */
+
 #ifndef WATCHDOG_H
 #define WATCHDOG_H
 
-#if IS_ENABLED(CONFIG_USE_WATCHDOG_ON_BOOT)
+#if CONFIG(USE_WATCHDOG_ON_BOOT)
 void watchdog_off(void);
 #else
 #define watchdog_off() { while (0); }
