@@ -183,7 +183,6 @@ static void merge_add_memranges(struct memranges *ranges,
 		/* The new entry starts after this one. */
 		if (begin > cur->end)
 			continue;
-
 	}
 
 	/* Add new entry and merge with neighbors. */
@@ -389,7 +388,6 @@ memranges_find_entry(struct memranges *ranges, resource_t limit, resource_t size
 		return NULL;
 
 	memranges_each_entry(r, ranges) {
-
 		if (r->tag != tag)
 			continue;
 
@@ -427,11 +425,12 @@ bool memranges_steal(struct memranges *ranges, resource_t limit, resource_t size
 		return false;
 
 	if (from_top) {
+		limit = MIN(limit, r->end);
 		/* Ensure we're within the range, even aligned down.
 		   Proof is simple: If ALIGN_UP(r->begin) would be
 		   higher, the stolen range wouldn't fit.*/
-		assert(r->begin <= ALIGN_DOWN(range_entry_end(r) - size, POWER_OF_2(align)));
-		*stolen_base = ALIGN_DOWN(range_entry_end(r) - size, POWER_OF_2(align));
+		assert(r->begin <= ALIGN_DOWN(limit - size + 1, POWER_OF_2(align)));
+		*stolen_base = ALIGN_DOWN(limit - size + 1, POWER_OF_2(align));
 	} else {
 		*stolen_base = ALIGN_UP(r->begin, POWER_OF_2(align));
 	}
