@@ -102,7 +102,7 @@ static const char *timestamp_name(enum timestamp_id id)
 }
 
 static void timestamp_add_table_entry(struct timestamp_table *ts_table,
-				      enum timestamp_id id, uint64_t ts_time)
+				      enum timestamp_id id, int64_t ts_time)
 {
 	struct timestamp_entry *tse;
 
@@ -114,10 +114,10 @@ static void timestamp_add_table_entry(struct timestamp_table *ts_table,
 	tse->entry_stamp = ts_time;
 
 	if (ts_table->num_entries == ts_table->max_entries)
-		printk(BIOS_ERR, "ERROR: Timestamp table full\n");
+		printk(BIOS_ERR, "Timestamp table full\n");
 }
 
-void timestamp_add(enum timestamp_id id, uint64_t ts_time)
+void timestamp_add(enum timestamp_id id, int64_t ts_time)
 {
 	struct timestamp_table *ts_table;
 
@@ -127,7 +127,7 @@ void timestamp_add(enum timestamp_id id, uint64_t ts_time)
 	ts_table = timestamp_table_get();
 
 	if (!ts_table) {
-		printk(BIOS_ERR, "ERROR: No timestamp table found\n");
+		printk(BIOS_ERR, "No timestamp table found\n");
 		return;
 	}
 
@@ -135,7 +135,7 @@ void timestamp_add(enum timestamp_id id, uint64_t ts_time)
 	timestamp_add_table_entry(ts_table, id, ts_time);
 
 	if (CONFIG(TIMESTAMPS_ON_CONSOLE))
-		printk(BIOS_INFO, "Timestamp - %s: %llu\n", timestamp_name(id), ts_time);
+		printk(BIOS_INFO, "Timestamp - %s: %lld\n", timestamp_name(id), ts_time);
 }
 
 void timestamp_add_now(enum timestamp_id id)
@@ -155,7 +155,7 @@ void timestamp_init(uint64_t base)
 	ts_cache = timestamp_cache_get();
 
 	if (!ts_cache) {
-		printk(BIOS_ERR, "ERROR: No timestamp cache to init\n");
+		printk(BIOS_ERR, "No timestamp cache to init\n");
 		return;
 	}
 
@@ -170,7 +170,7 @@ static void timestamp_sync_cache_to_cbmem(struct timestamp_table *ts_cbmem_table
 
 	ts_cache_table = timestamp_table_get();
 	if (!ts_cache_table) {
-		printk(BIOS_ERR, "ERROR: No timestamp cache found\n");
+		printk(BIOS_ERR, "No timestamp cache found\n");
 		return;
 	}
 
@@ -215,7 +215,7 @@ static void timestamp_reinit(int is_recovery)
 
 	/* First time into romstage we make a clean new table. For platforms that travel
 	   through this path on resume, ARCH_X86 S3, timestamps are also reset. */
-	if (ENV_ROMSTAGE) {
+	if (ENV_CREATES_CBMEM) {
 		ts_cbmem_table = timestamp_alloc_cbmem_table();
 	} else {
 		/* Find existing table in cbmem. */
@@ -223,12 +223,12 @@ static void timestamp_reinit(int is_recovery)
 	}
 
 	if (ts_cbmem_table == NULL) {
-		printk(BIOS_ERR, "ERROR: No timestamp table allocated\n");
+		printk(BIOS_ERR, "No timestamp table allocated\n");
 		timestamp_table_set(NULL);
 		return;
 	}
 
-	if (ENV_ROMSTAGE)
+	if (ENV_CREATES_CBMEM)
 		timestamp_sync_cache_to_cbmem(ts_cbmem_table);
 
 	/* Seed the timestamp tick frequency in ENV_PAYLOAD_LOADER. */
@@ -253,7 +253,7 @@ void timestamp_rescale_table(uint16_t N, uint16_t M)
 
 	/* No timestamp table found */
 	if (ts_table == NULL) {
-		printk(BIOS_ERR, "ERROR: No timestamp table found\n");
+		printk(BIOS_ERR, "No timestamp table found\n");
 		return;
 	}
 
@@ -279,9 +279,7 @@ uint32_t get_us_since_boot(void)
 	return (timestamp_get() - ts->base_time) / ts->tick_freq_mhz;
 }
 
-ROMSTAGE_CBMEM_INIT_HOOK(timestamp_reinit)
-POSTCAR_CBMEM_INIT_HOOK(timestamp_reinit)
-RAMSTAGE_CBMEM_INIT_HOOK(timestamp_reinit)
+CBMEM_READY_HOOK(timestamp_reinit);
 
 /* Provide default timestamp implementation using monotonic timer. */
 uint64_t  __weak timestamp_get(void)
