@@ -8,7 +8,7 @@ const u32 cim_verb_data[] = {
 	15,		/* Number of 4 dword sets */
 	AZALIA_SUBVENDOR(0, 0x104384fb),
 	AZALIA_PIN_CFG(0, 0x11, 0x99430140),
-	AZALIA_PIN_CFG(0, 0x12, 0x411111f0),
+	AZALIA_PIN_CFG(0, 0x12, AZALIA_PIN_CFG_NC(0)),
 	AZALIA_PIN_CFG(0, 0x14, 0x01014010),
 	AZALIA_PIN_CFG(0, 0x15, 0x01011012),
 	AZALIA_PIN_CFG(0, 0x16, 0x01016011),
@@ -17,10 +17,10 @@ const u32 cim_verb_data[] = {
 	AZALIA_PIN_CFG(0, 0x19, 0x02a19c60),
 	AZALIA_PIN_CFG(0, 0x1a, 0x0181305f),
 	AZALIA_PIN_CFG(0, 0x1b, 0x02214c20),
-	AZALIA_PIN_CFG(0, 0x1c, 0x411111f0),
+	AZALIA_PIN_CFG(0, 0x1c, AZALIA_PIN_CFG_NC(0)),
 	AZALIA_PIN_CFG(0, 0x1d, 0x4005e601),
 	AZALIA_PIN_CFG(0, 0x1e, 0x01456130),
-	AZALIA_PIN_CFG(0, 0x1f, 0x411111f0),
+	AZALIA_PIN_CFG(0, 0x1f, AZALIA_PIN_CFG_NC(0)),
 
 	0x80862806,	/* Codec Vendor / Device ID: Intel HDMI */
 	0x80860101,	/* Subsystem ID */
