@@ -1,12 +1,17 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
-#include <assert.h>
+#include <bootstate.h>
 #include <baseboard/variants.h>
 #include <chip.h>
 #include <device/device.h>
 #include <fw_config.h>
 #include <sar.h>
 
+#include "gpio.h"
+
+#define WWAN_RSL_L		GPP_H23
+#define WWAN_FCPO_L		GPP_F21
+
 void variant_update_soc_chip_config(struct soc_intel_alderlake_config *config)
 {
 	if (fw_config_probe(FW_CONFIG(WIFI_BT, WIFI_BT_CNVI)) || (!fw_config_is_provisioned())) {
@@ -25,25 +30,17 @@ const char *get_wifi_sar_cbfs_filename(void)
 	return get_wifi_sar_fw_config_filename(FW_CONFIG_FIELD(WIFI_BT));
 }
 
-void variant_devtree_update(void)
+const char *variant_get_auxfw_version_file(void)
 {
-	struct device *ufs = DEV_PTR(ufs);
-	struct device *ish = DEV_PTR(ish);
-	struct device *nvme_rp = DEV_PTR(pcie4_0);
+	return "rts5453_retimer_bypass.hash";
+}
 
-	if (fw_config_probe(FW_CONFIG(STORAGE, STORAGE_UNKNOWN)) || (!fw_config_is_provisioned())) {
-		printk(BIOS_INFO, "fw_config is unprovisioned or storage is unknown so enable all storage's configs.\n");
-		return;
-	}
-
-	if (!fw_config_probe(FW_CONFIG(STORAGE, STORAGE_NVME))) {
-		printk(BIOS_INFO, "NVMe disabled by fw_config.\n");
-		nvme_rp->enabled = 0;
-	}
-
-	if (!fw_config_probe(FW_CONFIG(STORAGE, STORAGE_UFS))) {
-		printk(BIOS_INFO, "UFS disabled by fw_config.\n");
-		ufs->enabled = 0;
-		ish->enabled = 0;
+static void wwan_out_of_reset(void *unused)
+{
+	if (fw_config_probe(FW_CONFIG(DB_USB, DB_1A_LTE)) ||
+		fw_config_probe(FW_CONFIG(DB_USB, DB_1A_LTE_SAR))) {
+		gpio_set(WWAN_FCPO_L, 1);
+		gpio_set(WWAN_RSL_L, 1);
 	}
 }
+BOOT_STATE_INIT_ENTRY(BS_DEV_ENABLE, BS_ON_ENTRY, wwan_out_of_reset, NULL);
