@@ -12,10 +12,10 @@
 #include <gpio.h>
 #include <intelblocks/power_limit.h>
 #include <smbios.h>
-#include <soc/gpio.h>
 #include <soc/pci_devs.h>
 #include <soc/nhlt.h>
-#include <string.h>
+#include <static.h>
+#include <stdio.h>
 #include <timer.h>
 
 #include <variant/gpio.h>
@@ -180,6 +180,25 @@ const char *smbios_system_sku(void)
 	return sku_str;
 }
 
+const char *fizz_oem_name[] = {
+	"Kench",
+	"Teemo",
+	"Sion",
+	"Wukong",
+	"Wukong",
+	"Wukong",
+	"Teemo",
+	"Karma",
+	"Jax",
+	"Endeavour",
+	"Excelsior"
+};
+
+const char *smbios_mainboard_product_name(void)
+{
+	return fizz_oem_name[board_oem_id()];
+}
+
 static void mainboard_init(struct device *dev)
 {
 	mainboard_ec_init();
