@@ -3,7 +3,7 @@
 #ifndef __BASEBOARD_GPIO_H__
 #define __BASEBOARD_GPIO_H__
 
-#include <soc/gpio.h>
+#include <gpio.h>
 
 /* SPI Write protect */
 #define CROS_WP_GPIO GPIO_67
