@@ -8,13 +8,16 @@
 #include <delay.h>
 #include <device/device.h>
 #include <device/mmio.h>
+#include <ec/google/chromeec/ec.h>
 #include <edid.h>
 #include <soc/clock.h>
 #include <soc/display/mdssreg.h>
 #include <soc/display/edp_ctrl.h>
+#include <soc/pcie.h>
 #include <soc/qupv3_config_common.h>
 #include <soc/qup_se_handlers_common.h>
 #include <soc/qcom_qup_se.h>
+#include <soc/sdhci.h>
 #include <soc/usb/usb_common.h>
 #include <soc/usb/snps_usb_phy.h>
 
@@ -36,9 +39,9 @@ static void setup_usb(void)
 static void configure_sdhci(void)
 {
 	/* Program eMMC drive strength to 16/10/10 mA */
-	write32((void *)SDC1_TLMM_CFG_ADDR, 0x9FE4);
+	write32p(SDC1_TLMM_CFG_ADDR, 0x9FE4);
 	/* Program SD card drive strength to 16/10/10 mA */
-	write32((void *)SDC2_TLMM_CFG_ADDR, 0x1FE4);
+	write32p(SDC2_TLMM_CFG_ADDR, 0x1FE4);
 }
 
 static void qi2s_configure_gpios(void)
@@ -82,10 +85,33 @@ static void display_startup(void)
 	}
 }
 
+/*
+ * Determine if board need to perform PCIe initialization.  Will return true if
+ * NVMe initialization is needed, or false if it is an eMMC device.  On
+ * Herobrine, if it is an NVMe enabled platform, logical sku_id & 2 will be
+ * true.
+ */
+bool mainboard_needs_pcie_init(void)
+{
+	uint32_t sku = sku_id();
+
+	if (sku == CROS_SKU_UNKNOWN) {
+		printk(BIOS_WARNING, "Unknown SKU (%#x); assuming PCIe", sku);
+		return true;
+	} else if (sku == CROS_SKU_UNPROVISIONED) {
+		printk(BIOS_WARNING, "Unprovisioned SKU (%#x); assuming PCIe", sku);
+		return true;
+	}
+
+	return !!(sku & 0x2);
+}
+
 static void mainboard_init(struct device *dev)
 {
 	/* Configure clock for eMMC */
 	clock_configure_sdcc1(384 * MHz);
+	qc_emmc_early_init();
+
 	/* Configure clock for SD card */
 	clock_configure_sdcc2(50 * MHz);
 	configure_sdhci();
@@ -147,6 +173,5 @@ static void mainboard_enable(struct device *dev)
 }
 
 struct chip_operations mainboard_ops = {
-	.name = CONFIG_MAINBOARD_PART_NUMBER,
 	.enable_dev = mainboard_enable,
 };
