@@ -1,6 +1,5 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
-#include <console/console.h>
 #include <bootmode.h>
 #include <boot/coreboot_tables.h>
 #include <device/pci_ops.h>
@@ -8,9 +7,10 @@
 
 #include <southbridge/intel/bd82x6x/pch.h>
 #include <southbridge/intel/common/gpio.h>
-#include <ec/compal/ene932/ec.h>
+#include <types.h>
 #include <vendorcode/google/chromeos/chromeos.h>
-#include "ec.h"
+
+#include "onboard.h"
 
 void fill_lb_gpios(struct lb_gpios *gpios)
 {
@@ -19,7 +19,7 @@ void fill_lb_gpios(struct lb_gpios *gpios)
 
 	struct lb_gpio chromeos_gpios[] = {
 		/* Lid switch GPIO active high (open). */
-		{15, ACTIVE_HIGH, get_lid_switch(), "lid"},
+		{GPIO_LID, ACTIVE_HIGH, get_lid_switch(), "lid"},
 
 		/* Power Button */
 		{101, ACTIVE_LOW, (gen_pmcon_1 >> 9) & 1, "power"},
@@ -33,38 +33,28 @@ void fill_lb_gpios(struct lb_gpios *gpios)
 
 int get_lid_switch(void)
 {
-	return get_gpio(15);
+	return get_gpio(GPIO_LID);
 }
 
 int get_write_protect_state(void)
 {
-	return !get_gpio(70);
+	return !get_gpio(GPIO_SPI_WP);
 }
 
 int get_recovery_mode_switch(void)
 {
-	u8 gpio = !get_gpio(68);
-	/* GPIO68, active low. For Servo support
-	 * Treat as active high and let the caller invert if needed. */
-	printk(BIOS_DEBUG, "REC MODE GPIO 68: %x\n", gpio);
-
-	return gpio;
-}
-
-static int parrot_ec_running_ro(void)
-{
-	return !get_gpio(68);
+	return !get_gpio(GPIO_REC_MODE);
 }
 
 static const struct cros_gpio cros_gpios[] = {
 	CROS_GPIO_REC_AH(CROS_GPIO_VIRTUAL, CROS_GPIO_DEVICE_NAME),
-	CROS_GPIO_WP_AL(70, CROS_GPIO_DEVICE_NAME),
+	CROS_GPIO_WP_AL(GPIO_SPI_WP, CROS_GPIO_DEVICE_NAME),
 };
+DECLARE_CROS_GPIOS(cros_gpios);
 
-void mainboard_chromeos_acpi_generate(void)
+int get_ec_is_trusted(void)
 {
-	if (CONFIG(CHROMEOS_NVS) && !parrot_ec_running_ro())
-		chromeos_set_ecfw_rw();
-
-	chromeos_acpi_gpio_generate(cros_gpios, ARRAY_SIZE(cros_gpios));
+	/* Do not have a Chrome EC involved in entering recovery mode;
+	   Always return trusted. */
+	return 1;
 }
