@@ -10,13 +10,13 @@ const u32 cim_verb_data[] = {
 
 	/* Pin Widget Verb Table */
 	AZALIA_PIN_CFG(0, 0x14, 0x01014410),
-	AZALIA_PIN_CFG(0, 0x15, 0x411111f0),
-	AZALIA_PIN_CFG(0, 0x16, 0x411111f0),
+	AZALIA_PIN_CFG(0, 0x15, AZALIA_PIN_CFG_NC(0)),
+	AZALIA_PIN_CFG(0, 0x16, AZALIA_PIN_CFG_NC(0)),
 	AZALIA_PIN_CFG(0, 0x18, 0x01a19840),
 	AZALIA_PIN_CFG(0, 0x19, 0x02a19841),
 	AZALIA_PIN_CFG(0, 0x1a, 0x0181304f),
 	AZALIA_PIN_CFG(0, 0x1b, 0x02214420),
-	AZALIA_PIN_CFG(0, 0x1c, 0x411111f0),
+	AZALIA_PIN_CFG(0, 0x1c, AZALIA_PIN_CFG_NC(0)),
 	AZALIA_PIN_CFG(0, 0x1d, 0x4015c603),
 	AZALIA_PIN_CFG(0, 0x1e, 0x99430130),
 };
