@@ -2,14 +2,13 @@
 #include "board_id.h"
 #include <ec/acpi/ec.h>
 #include <stdint.h>
-#include <stddef.h>
 
 /*
  * Get Board info via EC I/O port write/read
  */
 int get_ec_boardinfo(void)
 {
-	MAYBE_STATIC_NONZERO int ec_info = -1;
+	static int ec_info = -1;
 	if (ec_info < 0) {
 		uint8_t buffer[2];
 		uint8_t index;
