@@ -12,11 +12,11 @@ const u32 cim_verb_data[] = {
 	AZALIA_PIN_CFG(0, 0x15, 0x03211020),
 	AZALIA_PIN_CFG(0, 0x17, 0x40008000),
 	AZALIA_PIN_CFG(0, 0x18, 0x03a11030),
-	AZALIA_PIN_CFG(0, 0x19, 0x411111f0),
-	AZALIA_PIN_CFG(0, 0x1a, 0x411111f0),
-	AZALIA_PIN_CFG(0, 0x1b, 0x411111f0),
+	AZALIA_PIN_CFG(0, 0x19, AZALIA_PIN_CFG_NC(0)),
+	AZALIA_PIN_CFG(0, 0x1a, AZALIA_PIN_CFG_NC(0)),
+	AZALIA_PIN_CFG(0, 0x1b, AZALIA_PIN_CFG_NC(0)),
 	AZALIA_PIN_CFG(0, 0x1d, 0x40f38205),
-	AZALIA_PIN_CFG(0, 0x1e, 0x411111f0),
+	AZALIA_PIN_CFG(0, 0x1e, AZALIA_PIN_CFG_NC(0)),
 
 	0x80862806,	/* Codec Vendor / Device ID: Intel */
 	0x80860101,	/* Subsystem ID */
