@@ -6,19 +6,12 @@
 #include <device/device.h>
 #include <southbridge/intel/bd82x6x/pch.h>
 #include <southbridge/intel/common/gpio.h>
+#include <types.h>
 #include <vendorcode/google/chromeos/chromeos.h>
-
-#define GPIO_SPI_WP	68
-#define GPIO_REC_MODE	42
-
-#define FLAG_SPI_WP	0
-#define FLAG_REC_MODE	1
+#include "onboard.h"
 
 void fill_lb_gpios(struct lb_gpios *gpios)
 {
-	const pci_devfn_t dev = PCI_DEV(0, 0x1f, 0);
-	u16 gen_pmcon_1 = pci_s_read_config32(dev, GEN_PMCON_1);
-
 	struct lb_gpio chromeos_gpios[] = {
 		/* Recovery: GPIO42 = CHP3_REC_MODE# */
 		{GPIO_REC_MODE, ACTIVE_LOW, !get_recovery_mode_switch(),
@@ -28,7 +21,7 @@ void fill_lb_gpios(struct lb_gpios *gpios)
 		{100, ACTIVE_HIGH, 1, "lid"},
 
 		/* Power Button */
-		{101, ACTIVE_LOW, (gen_pmcon_1 >> 9) & 1, "power"},
+		{101, ACTIVE_LOW, get_power_switch(), "power"},
 
 		/* Did we load the VGA Option ROM? */
 		/* -1 indicates that this is a pseudo GPIO */
@@ -39,29 +32,19 @@ void fill_lb_gpios(struct lb_gpios *gpios)
 
 int get_write_protect_state(void)
 {
-	const pci_devfn_t dev = PCI_DEV(0, 0x1f, 2);
-	return (pci_s_read_config32(dev, SATA_SP) >> FLAG_SPI_WP) & 1;
+	return get_gpio(GPIO_SPI_WP);
 }
 
 int get_recovery_mode_switch(void)
 {
-	const pci_devfn_t dev = PCI_DEV(0, 0x1f, 2);
-	return (pci_s_read_config32(dev, SATA_SP) >> FLAG_REC_MODE) & 1;
+	return !get_gpio(GPIO_REC_MODE);
 }
 
-void init_bootmode_straps(void)
+int get_power_switch(void)
 {
-	u32 flags = 0;
-	const pci_devfn_t dev = PCI_DEV(0, 0x1f, 2);
-
-	/* Write Protect: GPIO68 = CHP3_SPI_WP, active high */
-	if (get_gpio(GPIO_SPI_WP))
-		flags |= (1 << FLAG_SPI_WP);
-	/* Recovery: GPIO42 = CHP3_REC_MODE#, active low */
-	if (!get_gpio(GPIO_REC_MODE))
-		flags |= (1 << FLAG_REC_MODE);
-
-	pci_s_write_config32(dev, SATA_SP, flags);
+	const pci_devfn_t dev = PCI_DEV(0, 0x1f, 0);
+	u16 gen_pmcon_1 = pci_s_read_config32(dev, GEN_PMCON_1);
+	return (gen_pmcon_1 >> 9) & 1;
 }
 
 static const struct cros_gpio cros_gpios[] = {
@@ -69,7 +52,4 @@ static const struct cros_gpio cros_gpios[] = {
 	CROS_GPIO_WP_AH(GPIO_SPI_WP, CROS_GPIO_DEVICE_NAME),
 };
 
-void mainboard_chromeos_acpi_generate(void)
-{
-	chromeos_acpi_gpio_generate(cros_gpios, ARRAY_SIZE(cros_gpios));
-}
+DECLARE_CROS_GPIOS(cros_gpios);
