@@ -1,7 +1,5 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
-#include <console/console.h>
-#include <option.h>
 #include <soc/romstage.h>
 #include <spd_bin.h>
 #include <string.h>
@@ -19,8 +17,4 @@ void mainboard_memory_init_params(FSPM_UPD *mupd)
 	mem_cfg->MemorySpdPtr00 = spd_cbfs_map(6);
 	mem_cfg->MemorySpdPtr10 = mem_cfg->MemorySpdPtr00;
 	mem_cfg->MemorySpdDataLen = CONFIG_DIMM_SPD_SIZE;
-
-	const uint8_t ht = get_uint_option("hyper_threading",
-		mupd->FspmConfig.HyperThreading);
-	mupd->FspmConfig.HyperThreading = ht;
 }
