@@ -9,11 +9,13 @@ void mainboard_memory_init_params(FSPM_UPD *mupd)
 {
 	const struct mb_cfg mem_config = {
 		.type = MEM_TYPE_DDR5,
+		.ect = true,
+		.UserBd = BOARD_TYPE_ULT_ULX,
 	};
 
 	const bool half_populated = false;
 
-	const struct mem_spd ddr4_spd_info = {
+	const struct mem_spd ddr5_spd_info = {
 		.topo = MEM_TOPO_DIMM_MODULE,
 		.smbus = {
 			[0] = {
@@ -25,7 +27,7 @@ void mainboard_memory_init_params(FSPM_UPD *mupd)
 		},
 	};
 
-	memcfg_init(mupd, &mem_config, &ddr4_spd_info, half_populated);
+	memcfg_init(mupd, &mem_config, &ddr5_spd_info, half_populated);
 
 	const uint8_t vtd = get_uint_option("vtd", 1);
 	mupd->FspmConfig.VtdDisable = !vtd;
@@ -34,5 +36,6 @@ void mainboard_memory_init_params(FSPM_UPD *mupd)
 	if (get_uint_option("wireless", 1) == 0)
 		mupd->FspmConfig.PcieRpEnableMask &= ~(1 << 8);
 
-	mupd->FspmConfig.PchHdaSubSystemIds = 0x14f1035e;
+	mupd->FspmConfig.PchHdaSubSystemIds = 0x70381e50;
+	mupd->FspmConfig.PsysPmax = 0;
 };
