@@ -1,6 +1,8 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
+#include <drivers/intel/gma/opregion.h>
 #include <soc/ramstage.h>
+#include <option.h>
 
 void mainboard_silicon_init_params(FSP_S_CONFIG *supd)
 {
@@ -13,3 +15,11 @@ void mainboard_silicon_init_params(FSP_S_CONFIG *supd)
 	supd->PchSerialIoI2cSdaPinMux[0]	= 0x1947c404;	// GPP_H4
 	supd->PchSerialIoI2cSclPinMux[0]	= 0x1947a405;	// GPP_H5
 }
+
+const char *mainboard_vbt_filename(void)
+{
+	if (get_uint_option("display_native_res", 0) == 1)
+		return "vbt_native_res.bin";
+
+	return "vbt.bin";
+}
