@@ -1,5 +1,6 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
+#include <commonlib/bsd/gcd.h>
 #include <console/console.h>
 #include <cpu/intel/model_2065x/model_2065x.h>
 #include <cpu/x86/msr.h>
@@ -11,29 +12,12 @@
 
 #define NORTHBRIDGE PCI_DEV(0, 0, 0)
 
-static unsigned int gcd(unsigned int a, unsigned int b)
-{
-	unsigned int t;
-	if (a > b) {
-		t = a;
-		a = b;
-		b = t;
-	}
-	/* invariant a < b.  */
-	while (a) {
-		t = b % a;
-		b = a;
-		a = t;
-	}
-	return b;
-}
-
 static inline int div_roundup(int a, int b)
 {
 	return DIV_ROUND_UP(a, b);
 }
 
-static unsigned int lcm(unsigned int a, unsigned int b)
+static u32 lcm(u32 a, u32 b)
 {
 	return (a * b) / gcd(a, b);
 }
@@ -611,9 +595,9 @@ void late_quickpath_init(struct raminfo *info, const int s3resume)
 	if (deven & 8) {
 		mchbar_setbits32(0xff8, 3 << 11);
 		mchbar_clrbits32(0x2cb0, ~0);
-		pci_read_config8(PCI_DEV (0, 0x2, 0x0), 0x4c);
-		pci_read_config8(PCI_DEV (0, 0x2, 0x0), 0x4c);
-		pci_read_config8(PCI_DEV (0, 0x2, 0x0), 0x4e);
+		pci_read_config8(PCI_DEV(0, 0x2, 0x0), 0x4c);
+		pci_read_config8(PCI_DEV(0, 0x2, 0x0), 0x4c);
+		pci_read_config8(PCI_DEV(0, 0x2, 0x0), 0x4e);
 
 		mchbar_read8(0x1150);
 		mchbar_read8(0x1151);
