@@ -52,19 +52,16 @@ static void get_smm_info(uintptr_t *perm_smbase, size_t *perm_smsize,
 	*smm_save_state_size = sizeof(amd64_smm_state_save_area_t);
 }
 
-static void tseg_valid(void)
-{
-	msr_t mask = rdmsr(SMM_MASK_MSR);
-	mask.lo |= SMM_TSEG_VALID;
-
-	wrmsr(SMM_MASK_MSR, mask);
-}
-
 static void smm_relocation_handler(void)
 {
 	uintptr_t tseg_base;
 	size_t tseg_size;
 
+	/* For the TSEG masks all physical address bits including the ones reserved for memory
+	   encryption need to be taken into account. TODO: Find out why this is the case */
+	const unsigned int total_physical_address_bits =
+		cpu_phys_address_size() + get_reserved_phys_addr_bits();
+
 	smm_region(&tseg_base, &tseg_size);
 
 	msr_t msr;
@@ -73,7 +70,7 @@ static void smm_relocation_handler(void)
 
 	msr.lo = ~(tseg_size - 1);
 	msr.lo |= SMM_TSEG_WB;
-	msr.hi = (1 << (cpu_phys_address_size() - 32)) - 1;
+	msr.hi = (1 << (total_physical_address_bits - 32)) - 1;
 	wrmsr(SMM_MASK_MSR, msr);
 
 	uintptr_t smbase = smm_get_cpu_smbase(cpu_index());
@@ -82,8 +79,11 @@ static void smm_relocation_handler(void)
 	};
 	wrmsr(SMM_BASE_MSR, smm_base);
 
-	tseg_valid();
-	lock_smm();
+
+	if (!CONFIG(SOC_AMD_COMMON_LATE_SMM_LOCKING)) {
+		tseg_valid();
+		lock_smm();
+	}
 }
 
 static void post_mp_init(void)
