@@ -23,18 +23,16 @@
  */
 static uint16_t ddr_speed_mhz_to_reported_mts(uint16_t ddr_type, uint16_t speed)
 {
-	switch (ddr_type) {
-	case MEMORY_TYPE_DDR4:
+	if (CONFIG(USE_DDR4) && ddr_type == MEMORY_TYPE_DDR4)
 		return ddr4_speed_mhz_to_reported_mts(speed);
-	case MEMORY_TYPE_LPDDR4:
+	else if (CONFIG(USE_LPDDR4) && ddr_type == MEMORY_TYPE_LPDDR4)
 		return lpddr4_speed_mhz_to_reported_mts(speed);
-	case MEMORY_TYPE_DDR5:
-	case MEMORY_TYPE_LPDDR5:
+	else if (CONFIG(USE_DDR5) && (ddr_type == MEMORY_TYPE_DDR5 ||
+			ddr_type == MEMORY_TYPE_LPDDR5))
 		return ddr5_speed_mhz_to_reported_mts(speed);
-	default:
-		printk(BIOS_ERR, "Unknown memory type %x\n", ddr_type);
-		return 0;
-	}
+
+	printk(BIOS_ERR, "Unknown memory type %x\n", ddr_type);
+	return 0;
 }
 
 /**
@@ -173,7 +171,7 @@ static void print_dmi_info(const TYPE17_DMI_INFO *dmi17)
 /**
  * Marshalls dimm info from AMD_FSP_DMI_HOB into CBMEM_ID_MEMINFO
  */
-static void prepare_dmi_17(void *unused)
+static void prepare_dmi_16_17(void *unused)
 {
 	const DMI_INFO *dmi_table;
 	const TYPE17_DMI_INFO *type17_dmi_info;
@@ -217,8 +215,8 @@ static void prepare_dmi_17(void *unused)
 		}
 	}
 
-	for (unsigned int channel = 0; channel < MAX_CHANNELS_PER_SOCKET; channel++) {
-		for (unsigned int dimm = 0; dimm < MAX_DIMMS_PER_CHANNEL; dimm++) {
+	for (unsigned int channel = 0; channel < AGESA_STRUCT_CHANNELS_PER_SOCKET; channel++) {
+		for (unsigned int dimm = 0; dimm < AGESA_STRUCT_DIMMS_PER_CHANNEL; dimm++) {
 			type17_dmi_info = &dmi_table->T17[0][channel][dimm];
 			/* DIMMs that are present will have a non-zero
 			   handle. */
@@ -227,7 +225,7 @@ static void prepare_dmi_17(void *unused)
 			print_dmi_info(type17_dmi_info);
 			dimm_info = &mem_info->dimm[dimm_cnt];
 			dimm_info->channel_num = channel;
-			dimm_info->dimm_num = channel;
+			dimm_info->dimm_num = dimm;
 			transfer_memory_info(type17_dmi_info, dimm_info);
 			if (use_cbi_part_number) {
 				/* mem_info is memset to 0 above, so it's
@@ -235,13 +233,31 @@ static void prepare_dmi_17(void *unused)
 				   null terminated */
 				strncpy((char *)dimm_info->module_part_number, cbi_part_number,
 					sizeof(dimm_info->module_part_number) - 1);
+
+				/* These ID values match what's used in device/dram/spd.c */
+				switch (dimm_info->module_part_number[0]) {
+				case 'H':
+					dimm_info->mod_id = 0xad00;	// Hynix
+					break;
+				case 'K':
+					dimm_info->mod_id = 0x9801;	// Kingston
+					break;
+				case 'M':
+					dimm_info->mod_id = 0x2c00;	// Micron
+					break;
+				case 'N':
+					dimm_info->mod_id = 0x0b83;	// Nanya
+					break;
+				}
 			}
 			print_dimm_info(dimm_info);
 			dimm_cnt++;
 		}
 	}
 	mem_info->dimm_cnt = dimm_cnt;
+
+	mem_info->ecc_type = dmi_table->T16.MemoryErrorCorrection;
 }
 
 /* AMD_FSP_DMI_HOB is initialized very late, so check it just in time for writing tables. */
-BOOT_STATE_INIT_ENTRY(BS_WRITE_TABLES, BS_ON_ENTRY, prepare_dmi_17, NULL);
+BOOT_STATE_INIT_ENTRY(BS_WRITE_TABLES, BS_ON_ENTRY, prepare_dmi_16_17, NULL);
