@@ -1,26 +1,19 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
-/* TODO: Check if this is still correct */
-
+#include <acpi/acpigen_pci.h>
+#include <amdblocks/acpi.h>
+#include <amdblocks/data_fabric.h>
+#include <amdblocks/fsp.h>
+#include <amdblocks/root_complex.h>
 #include <console/console.h>
 #include <device/device.h>
 #include <device/pci.h>
-#include <fsp/api.h>
-#include <soc/acpi.h>
 #include <soc/cpu.h>
-#include <soc/data_fabric.h>
 #include <soc/pci_devs.h>
 #include <soc/southbridge.h>
 #include <types.h>
 #include "chip.h"
 
-struct device_operations mendocino_cpu_bus_ops = {
-	.read_resources	= noop_read_resources,
-	.set_resources	= noop_set_resources,
-	.init		= mp_cpu_bus_init,
-	.acpi_fill_ssdt	= generate_cpu_entries,
-};
-
 static const char *soc_acpi_name(const struct device *dev)
 {
 	if (dev->path.type == DEVICE_PATH_DOMAIN)
@@ -35,19 +28,21 @@ static const char *soc_acpi_name(const struct device *dev)
 };
 
 struct device_operations mendocino_pci_domain_ops = {
-	.read_resources	= pci_domain_read_resources,
+	.read_resources	= amd_pci_domain_read_resources,
 	.set_resources	= pci_domain_set_resources,
-	.scan_bus	= pci_domain_scan_bus,
+	.scan_bus	= amd_pci_domain_scan_bus,
+	.init		= amd_pci_domain_init,
 	.acpi_name	= soc_acpi_name,
+	.acpi_fill_ssdt	= pci_domain_fill_ssdt,
 };
 
 static void soc_init(void *chip_info)
 {
-	default_dev_ops_root.write_acpi_tables = agesa_write_acpi_tables;
+	default_dev_ops_root.write_acpi_tables = soc_acpi_write_tables;
 
-	fsp_silicon_init();
+	amd_fsp_silicon_init();
 
-	data_fabric_set_mmio_np();
+	data_fabric_print_mmio_conf();
 
 	fch_init(chip_info);
 }
@@ -58,7 +53,7 @@ static void soc_final(void *chip_info)
 }
 
 struct chip_operations soc_amd_mendocino_ops = {
-	CHIP_NAME("AMD Mendocino SoC")
+	.name = "AMD Mendocino SoC",
 	.init = soc_init,
 	.final = soc_final
 };
