@@ -107,9 +107,25 @@ struct mb_cfg {
 
 	/* Enable/Disable TxDqDqs Retraining for Lp4/Lp5/DDR */
 	uint8_t LpDdrDqDqsReTraining;
+
+	/* Enable/Disable Cs Pi Start with High value in Ect */
+	uint8_t cs_pi_start_high_in_ect;
+
 };
 
 void memcfg_init(FSPM_UPD *memupd, const struct mb_cfg *mb_cfg,
 		 const struct mem_spd *spd_info, bool half_populated);
 
+/*
+ * This function is expected to return a bitmap of memory channels to
+ * disable. A set bit will disable corresponding memory channel.
+ * Variants can override this bitmap by selecting
+ * `ENFORCE_MEM_CHANNEL_DISABLE` and implementing this function.
+ */
+#if CONFIG(ENFORCE_MEM_CHANNEL_DISABLE)
+uint8_t mb_get_channel_disable_mask(void);
+#else
+static inline uint8_t mb_get_channel_disable_mask(void) { return 0; }
+#endif
+
 #endif /* _SOC_ALDERLAKE_MEMINIT_H_ */
