@@ -114,7 +114,7 @@ static void lpe_stash_firmware_info(struct device *dev)
 		printk(BIOS_DEBUG, "LPE Firmware memory not found.\n");
 		return;
 	}
-	printk(BIOS_DEBUG, "LPE FW Resource: 0x%08x\n", (u32) res->base);
+	printk(BIOS_DEBUG, "LPE FW Resource: 0x%08x\n", (u32)res->base);
 
 	/* Continue using old way of informing firmware address / size. */
 	pci_write_config32(dev, FIRMWARE_PCI_REG_BASE,   res->base);
@@ -154,8 +154,8 @@ static void lpe_read_resources(struct device *dev)
 	res->align = 12;
 	res->flags = IORESOURCE_MEM;
 
-	reserved_ram_resource_kb(dev, FIRMWARE_PCI_REG_BASE, FIRMWARE_PHYS_BASE >> 10,
-			      FIRMWARE_PHYS_LENGTH >> 10);
+	reserved_ram_range(dev, FIRMWARE_PCI_REG_BASE, FIRMWARE_PHYS_BASE,
+			   FIRMWARE_PHYS_LENGTH);
 }
 
 static void lpe_set_resources(struct device *dev)
