@@ -1,7 +1,8 @@
 /* SPDX-License-Identifier: GPL-2.0-or-later */
 
-#include <intelblocks/gpio.h>
+#include <gpio.h>
 #include <soc/soc_chip.h>
+#include <static.h>
 
 /*
  * Routine to perform below operations:
