@@ -67,6 +67,12 @@ struct device_operations pcie_rp_ops = {
 };
 
 static const unsigned short pcie_device_ids[] = {
+	PCI_DID_INTEL_WCL_PCIE_RP1,
+	PCI_DID_INTEL_WCL_PCIE_RP2,
+	PCI_DID_INTEL_WCL_PCIE_RP3,
+	PCI_DID_INTEL_WCL_PCIE_RP4,
+	PCI_DID_INTEL_WCL_PCIE_RP5,
+	PCI_DID_INTEL_WCL_PCIE_RP6,
 	PCI_DID_INTEL_PTL_H_PCIE_RP1,
 	PCI_DID_INTEL_PTL_H_PCIE_RP2,
 	PCI_DID_INTEL_PTL_H_PCIE_RP3,
@@ -100,6 +106,7 @@ static const unsigned short pcie_device_ids[] = {
 	PCI_DID_INTEL_RPL_P_PCIE_RP1,
 	PCI_DID_INTEL_RPL_P_PCIE_RP2,
 	PCI_DID_INTEL_RPL_P_PCIE_RP3,
+	PCI_DID_INTEL_RPL_P_PCIE_RP4,
 	PCI_DID_INTEL_MTL_SOC_PCIE_RP1,
 	PCI_DID_INTEL_MTL_SOC_PCIE_RP2,
 	PCI_DID_INTEL_MTL_SOC_PCIE_RP3,
@@ -112,6 +119,15 @@ static const unsigned short pcie_device_ids[] = {
 	PCI_DID_INTEL_MTL_IOE_P_PCIE_RP10,
 	PCI_DID_INTEL_MTL_IOE_P_PCIE_RP11,
 	PCI_DID_INTEL_MTL_IOE_P_PCIE_RP12,
+	PCI_DID_INTEL_ARL_SOC_PCIE_RP1,
+	PCI_DID_INTEL_ARL_SOC_PCIE_RP2,
+	PCI_DID_INTEL_ARL_SOC_PCIE_RP3,
+	PCI_DID_INTEL_ARL_SOC_PCIE_RP4,
+	PCI_DID_INTEL_ARL_SOC_PCIE_RP5,
+	PCI_DID_INTEL_ARL_SOC_PCIE_RP6,
+	PCI_DID_INTEL_ARL_SOC_PCIE_RP7,
+	PCI_DID_INTEL_ARL_SOC_PCIE_RP8,
+	PCI_DID_INTEL_ARL_SOC_PCIE_RP9,
 	PCI_DID_INTEL_LWB_PCIE_RP1,
 	PCI_DID_INTEL_LWB_PCIE_RP2,
 	PCI_DID_INTEL_LWB_PCIE_RP3,
