@@ -111,12 +111,14 @@ struct device_operations pmc_ops = {
 };
 
 static const unsigned short pci_device_ids[] = {
+	PCI_DID_INTEL_WCL_PMC,
 	PCI_DID_INTEL_PTL_H_PMC,
 	PCI_DID_INTEL_PTL_U_H_PMC,
 	PCI_DID_INTEL_LNL_PMC,
 	PCI_DID_INTEL_MTL_SOC_PMC,
 	PCI_DID_INTEL_MTL_IOE_M_PMC,
 	PCI_DID_INTEL_MTL_IOE_P_PMC,
+	PCI_DID_INTEL_ARL_SOC_PMC,
 	PCI_DID_INTEL_RPP_P_PMC,
 	PCI_DID_INTEL_DNV_PMC,
 	PCI_DID_INTEL_LWB_PMC,
