@@ -6,7 +6,6 @@
 #include <console/uart.h>
 #include <device/device.h>
 #include <device/pci.h>
-#include <device/pci_def.h>
 #include <device/pci_ids.h>
 #include <device/pci_ops.h>
 #include <intelblocks/irq.h>
@@ -15,7 +14,6 @@
 #include <soc/pci_devs.h>
 #include <soc/iomap.h>
 #include <soc/nvs.h>
-#include "chip.h"
 
 #define UART_PCI_ENABLE	(PCI_COMMAND_MEMORY | PCI_COMMAND_MASTER)
 
@@ -253,7 +251,9 @@ static void uart_fill_ssdt(const struct device *dev)
 
 	acpi_device_write_uid(dev);
 	acpigen_write_name_string("_DDN", "LPSS ACPI UART");
-	acpigen_write_STA(acpi_device_status(dev));
+
+	/* Do not hide the UART device from the OS */
+	acpigen_write_STA(ACPI_STATUS_DEVICE_ALL_ON);
 
 	/* Resources */
 	acpigen_write_name("_CRS");
@@ -308,6 +308,10 @@ static const char *uart_acpi_hid(const struct device *dev)
 static const char *uart_acpi_name(const struct device *dev)
 {
 	switch (dev->device) {
+	case PCI_DID_INTEL_WCL_UART0:
+	case PCI_DID_INTEL_PTL_H_UART0:
+	case PCI_DID_INTEL_PTL_U_H_UART0:
+	case PCI_DID_INTEL_LNL_UART0:
 	case PCI_DID_INTEL_ADP_P_UART0:
 	case PCI_DID_INTEL_APL_UART0:
 	case PCI_DID_INTEL_GLK_UART0:
@@ -315,6 +319,10 @@ static const char *uart_acpi_name(const struct device *dev)
 	case PCI_DID_INTEL_SPT_H_UART0:
 	case PCI_DID_INTEL_CNP_H_UART0:
 		return "UAR0";
+	case PCI_DID_INTEL_WCL_UART1:
+	case PCI_DID_INTEL_PTL_H_UART1:
+	case PCI_DID_INTEL_PTL_U_H_UART1:
+	case PCI_DID_INTEL_LNL_UART1:
 	case PCI_DID_INTEL_ADP_P_UART1:
 	case PCI_DID_INTEL_APL_UART1:
 	case PCI_DID_INTEL_GLK_UART1:
@@ -322,6 +330,10 @@ static const char *uart_acpi_name(const struct device *dev)
 	case PCI_DID_INTEL_SPT_H_UART1:
 	case PCI_DID_INTEL_CNP_H_UART1:
 		return "UAR1";
+	case PCI_DID_INTEL_WCL_UART2:
+	case PCI_DID_INTEL_PTL_H_UART2:
+	case PCI_DID_INTEL_PTL_U_H_UART2:
+	case PCI_DID_INTEL_LNL_UART2:
 	case PCI_DID_INTEL_ADP_P_UART2:
 	case PCI_DID_INTEL_APL_UART2:
 	case PCI_DID_INTEL_GLK_UART2:
@@ -348,9 +360,24 @@ struct device_operations uart_ops = {
 };
 
 static const unsigned short pci_device_ids[] = {
+	PCI_DID_INTEL_WCL_UART0,
+	PCI_DID_INTEL_WCL_UART1,
+	PCI_DID_INTEL_WCL_UART2,
+	PCI_DID_INTEL_PTL_H_UART0,
+	PCI_DID_INTEL_PTL_H_UART1,
+	PCI_DID_INTEL_PTL_H_UART2,
+	PCI_DID_INTEL_PTL_U_H_UART0,
+	PCI_DID_INTEL_PTL_U_H_UART1,
+	PCI_DID_INTEL_PTL_U_H_UART2,
+	PCI_DID_INTEL_LNL_UART0,
+	PCI_DID_INTEL_LNL_UART1,
+	PCI_DID_INTEL_LNL_UART2,
 	PCI_DID_INTEL_MTL_UART0,
 	PCI_DID_INTEL_MTL_UART1,
 	PCI_DID_INTEL_MTL_UART2,
+	PCI_DID_INTEL_ARL_UART0,
+	PCI_DID_INTEL_ARL_UART1,
+	PCI_DID_INTEL_ARL_UART2,
 	PCI_DID_INTEL_APL_UART0,
 	PCI_DID_INTEL_APL_UART1,
 	PCI_DID_INTEL_APL_UART2,
@@ -405,6 +432,10 @@ static const unsigned short pci_device_ids[] = {
 	PCI_DID_INTEL_ADP_M_N_UART1,
 	PCI_DID_INTEL_ADP_M_N_UART2,
 	PCI_DID_INTEL_ADP_M_N_UART3,
+	PCI_DID_INTEL_RPP_S_UART0,
+	PCI_DID_INTEL_RPP_S_UART1,
+	PCI_DID_INTEL_RPP_S_UART2,
+	PCI_DID_INTEL_RPP_S_UART3,
 	0,
 };
 
@@ -413,17 +444,4 @@ static const struct pci_driver pch_uart __pci_driver = {
 	.vendor		= PCI_VID_INTEL,
 	.devices	= pci_device_ids,
 };
-
-static void uart_enable(struct device *dev)
-{
-	struct soc_intel_common_block_uart_config *conf = dev->chip_info;
-	dev->ops = &uart_ops;
-	dev->device = conf ? conf->devid : 0;
-}
-
-struct chip_operations soc_intel_common_block_uart_ops = {
-	CHIP_NAME("LPSS UART in ACPI mode")
-	.enable_dev = uart_enable
-};
-
 #endif /* ENV_RAMSTAGE */
