@@ -3,6 +3,8 @@
 #ifndef _DENVERTON_NS_PMC_H_
 #define _DENVERTON_NS_PMC_H_
 
+#include <soc/intel/common/tco.h>
+
 /* Memory mapped IO registers behind PMC_BASE_ADDRESS */
 #define PMC_ACPI_BASE 0x40 /* IO BAR */
 #define MASK_PMC_ACPI_BASE 0xfffc
@@ -35,9 +37,13 @@
 #define   MASK_PMC_PWRM_BASE    0xfffff000 /* 4K alignment */
 #define GEN_PMCON_A               0xA0
 #define   MS4V                    (1 << 18)
+#define   GBL_RST_STS             (1 << 16)
 #define GEN_PMCON_B               0xA4
+#define   GEN_PMCON_B_SUS_PWR_FLR   0x4000
+#define   SUS_PWR_FLR               GEN_PMCON_B_SUS_PWR_FLR
 #define   GEN_PMCON_B_RTC_PWR_STS   0x04
 #define   GEN_PMCON_B_PWR_FLR       0x02
+#define   PWR_FLR                   GEN_PMCON_B_PWR_FLR
 #define   GEN_PMCON_B_AFTERG3_EN    0x00
 #define ETR3                      0xAC
 #define   ETR3_CF9LOCK              BIT31 ///< CF9h Lockdown
@@ -210,29 +216,6 @@
 #define SWGPE_EN (1 << 2)
 #define HOT_PLUG_EN (1 << 1)
 
-/* TCO registers and fields live behind TCOBASE I/O bar in SMBus device. */
-#define TCO_RLD 0x00
-#define TCO1_STS 0x04
-#define TCO1_STS_TCO_SLVSEL (1 << 13)
-#define TCO1_STS_CPUSERR (1 << 12)
-#define TCO1_STS_CPUSMI (1 << 10)
-#define TCO1_STS_CPUSCI (1 << 9)
-#define TCO1_STS_BIOSWR (1 << 8)
-#define TCO1_STS_NEWCENTURY (1 << 7)
-#define TCO1_STS_TIMEOUT (1 << 3)
-#define TCO1_STS_TCO_INT (1 << 2)
-#define TCO1_STS_OS_TCO_SMI (1 << 1)
-#define TCO1_STS_NMI2SMI (1 << 0)
-#define TCO2_STS 0x06
-#define TCO2_STS_SMLINK_SLAVE_SMI 0x04
-#define TCO2_STS_SECOND_TO 0x02
-#define TCO2_STS_INTRD_DET 0x01
-#define TCO1_CNT 0x08
-#define TCO_LOCK (1 << 12)
-#define TCO_TMR_HLT (1 << 11)
-#define TCO2_CNT 0x0a
-#define TCO_TMR 0x12
-
 /* Memory mapped IO registers behind PMC_BASE_ADDRESS */
 #define PRSTS			0x10
 #define GPIO_GPE_CFG		0x120
