@@ -329,7 +329,7 @@ void platform_fsp_silicon_init_params_cb(FSPS_UPD *supd)
 		params->PsfTccEnable = 1;
 		params->PmcLpmS0ixSubStateEnableMask = 0;
 		params->PchDmiAspmCtrl = 0;
-		params->PchLegacyIoLowLatency = 0;
+		params->PchLegacyIoLowLatency = 1;
 		params->EnableItbm = 0;
 		params->D3ColdEnable = 0;
 		params->PmcOsIdleEnable = 0;
@@ -505,6 +505,9 @@ void platform_fsp_silicon_init_params_cb(FSPS_UPD *supd)
 
 	/* Override/Fill FSP Silicon Param for mainboard */
 	mainboard_silicon_init_params(params);
+
+	/* Runtime configuration of S0ix */
+	config->s0ix_enable = get_uint_option("s0ix_enable", config->s0ix_enable);
 }
 
 /* Mainboard GPIO Configuration */
