@@ -1,11 +1,13 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
+#include <acpi/acpi.h>
 #include <assert.h>
 #include <bootmode.h>
 #include <console/console.h>
 #include <cpu/intel/common/common.h>
 #include <cpu/intel/cpu_ids.h>
 #include <cpu/x86/msr.h>
+#include <cpu/x86/mtrr.h>
 #include <device/device.h>
 #include <device/pci.h>
 #include <drivers/wifi/generic/wifi.h>
@@ -117,7 +119,7 @@ static void fill_fspm_igd_params(FSP_M_CONFIG *m_cfg,
 	m_cfg->InternalGfx = !CONFIG(SOC_INTEL_DISABLE_IGD) && is_devfn_enabled(PCI_DEVFN_IGD);
 	if (m_cfg->InternalGfx) {
 		/* IGD is enabled, set IGD stolen size to 128MB. */
-		m_cfg->IgdDvmt50PreAlloc = IGD_SM_128MB;
+		m_cfg->IgdDvmt50PreAlloc = get_uint_option("igd_dvmt_prealloc", IGD_SM_128MB);
 		/* DP port config */
 		m_cfg->DdiPortAConfig = config->ddi_port_A_config;
 		m_cfg->DdiPortBConfig = config->ddi_port_B_config;
@@ -190,7 +192,7 @@ static void fill_fspm_cpu_params(FSP_M_CONFIG *m_cfg,
 static void fill_tme_params(FSP_M_CONFIG *m_cfg)
 {
 	m_cfg->TmeEnable = CONFIG(INTEL_TME) && is_tme_supported();
-	if (!m_cfg->TmeEnable)
+	if (!m_cfg->TmeEnable || acpi_is_wakeup_s3())
 		return;
 	m_cfg->GenerateNewTmeKey = CONFIG(TME_KEY_REGENERATION_ON_WARM_BOOT) &&
 			 CONFIG(SOC_INTEL_COMMON_BASECODE_RAMTOP);
@@ -201,8 +203,8 @@ static void fill_tme_params(FSP_M_CONFIG *m_cfg)
 						"Full memory encryption is enabled.\n");
 			return;
 		}
-		m_cfg->TmeExcludeBase = (ram_top - 16*MiB);
-		m_cfg->TmeExcludeSize = 16*MiB;
+		m_cfg->TmeExcludeBase = (ram_top - CACHE_TMP_RAMTOP);
+		m_cfg->TmeExcludeSize = CACHE_TMP_RAMTOP;
 	}
 }
 
@@ -353,7 +355,7 @@ static void fill_fspm_usb4_params(FSP_M_CONFIG *m_cfg,
 static void fill_fspm_vtd_params(FSP_M_CONFIG *m_cfg,
 		const struct soc_intel_meteorlake_config *config)
 {
-	m_cfg->VtdDisable = 0;
+	m_cfg->VtdDisable = !get_uint_option("vtd", 1);
 	m_cfg->VtdBaseAddress[0] = GFXVT_BASE_ADDRESS;
 	m_cfg->VtdBaseAddress[1] = VTVC0_BASE_ADDRESS;
 
@@ -436,8 +438,6 @@ static void soc_memory_init_params(FSP_M_CONFIG *m_cfg,
 		fill_fspm_params[i](m_cfg, config);
 }
 
-#define UX_MEMORY_TRAINING_DESC	"memory_training_desc"
-
 #define VGA_INIT_CONTROL_ENABLE		BIT(0)
 /* Tear down legacy VGA mode before exiting FSP-M. */
 #define VGA_INIT_CONTROL_TEAR_DOWN	BIT(1)
@@ -465,12 +465,7 @@ static void fill_fspm_sign_of_life(FSP_M_CONFIG *m_cfg,
 	if (!vga_init_control)
 		return;
 
-	const char *text = ux_locales_get_text(UX_MEMORY_TRAINING_DESC);
-	/* No localized text found; fallback to built-in English. */
-	if (!text)
-		text = "Your device is finishing an update. "
-		       "This may take 1-2 minutes.\n"
-		       "Please do not turn off your device.";
+	const char *text = ux_locales_get_text(UX_LOCALE_MSG_MEMORY_TRAINING);
 
 	vbt = cbfs_map("vbt.bin", &vbt_size);
 	if (!vbt) {
