@@ -26,6 +26,8 @@
 #define MAX_SAGV_POINTS 4
 #define MAX_HD_AUDIO_SDI_LINKS 2
 
+#define NUM_THC 2
+
 /* In-Band ECC Operation Mode */
 enum ibecc_mode {
 	IBECC_MODE_PER_REGION,
@@ -42,8 +44,17 @@ struct ibecc_config {
 	uint16_t region_mask[MAX_IBECC_REGIONS];
 };
 
+/* SaGv gears */
+enum soc_intel_pantherlake_sagv_gears {
+	GEAR_AUTO = 0,
+	GEAR_1 = 1,
+	GEAR_2 = 2,
+	GEAR_4 = 4,
+};
+
 enum soc_intel_pantherlake_power_limits {
 	PTL_U_1_CORE,
+	PTL_U_2_CORE,
 	PTL_H_1_CORE,
 	PTL_H_2_CORE,
 	PTL_H_3_CORE,
@@ -57,17 +68,33 @@ enum soc_intel_pantherlake_cpu_tdps {
 	TDP_45W = 45,
 };
 
+enum soc_intel_pantherlake_sku {
+	PTL_H404_SKU,
+	PTL_H12XE_SKU,
+	PTL_H484_SKU,
+	PTL_H4XE_SKU,
+	PTL_H204_SKU,
+	MAX_PTL_SKUS
+};
+
 /* Mapping of different SKUs based on CPU ID and TDP values */
-static const struct {
+static const struct soc_intel_pantherlake_power_map {
 	unsigned int cpu_id;
 	enum soc_intel_pantherlake_power_limits limits;
 	enum soc_intel_pantherlake_cpu_tdps cpu_tdp;
+	enum soc_intel_pantherlake_sku sku;
 } cpuid_to_ptl[] = {
-	{ PCI_DID_INTEL_PTL_U_ID_1, PTL_U_1_CORE, TDP_15W },
-	{ PCI_DID_INTEL_PTL_H_ID_1, PTL_H_1_CORE, TDP_25W },
-	{ PCI_DID_INTEL_PTL_H_ID_2, PTL_H_1_CORE, TDP_25W },
-	{ PCI_DID_INTEL_PTL_H_ID_3, PTL_H_2_CORE, TDP_25W },
-	{ PCI_DID_INTEL_PTL_H_ID_4, PTL_H_2_CORE, TDP_25W },
+	{ PCI_DID_INTEL_PTL_U_ID_1, PTL_U_1_CORE, TDP_15W, PTL_H404_SKU },
+	{ PCI_DID_INTEL_PTL_U_ID_2, PTL_U_2_CORE, TDP_15W, PTL_H204_SKU },
+	{ PCI_DID_INTEL_PTL_U_ID_3, PTL_U_2_CORE, TDP_15W, PTL_H404_SKU },
+	{ PCI_DID_INTEL_PTL_H_ID_1, PTL_H_1_CORE, TDP_25W, PTL_H12XE_SKU },
+	{ PCI_DID_INTEL_PTL_H_ID_2, PTL_H_1_CORE, TDP_25W, PTL_H484_SKU },
+	{ PCI_DID_INTEL_PTL_H_ID_3, PTL_H_2_CORE, TDP_25W, PTL_H12XE_SKU },
+	{ PCI_DID_INTEL_PTL_H_ID_4, PTL_H_2_CORE, TDP_25W, PTL_H12XE_SKU },
+	{ PCI_DID_INTEL_PTL_H_ID_5, PTL_H_2_CORE, TDP_25W, PTL_H4XE_SKU },
+	{ PCI_DID_INTEL_PTL_H_ID_6, PTL_H_2_CORE, TDP_25W, PTL_H4XE_SKU },
+	{ PCI_DID_INTEL_PTL_H_ID_7, PTL_H_2_CORE, TDP_25W, PTL_H4XE_SKU },
+	{ PCI_DID_INTEL_PTL_H_ID_8, PTL_H_2_CORE, TDP_25W, PTL_H12XE_SKU },
 };
 
 /* Types of display ports */
@@ -121,6 +148,23 @@ enum lpm_state_mask {
 			| LPM_S0i3_0 | LPM_S0i3_1 | LPM_S0i3_2 | LPM_S0i3_3 | LPM_S0i3_4,
 };
 
+/* Platform Debug Option using HW interface
+ *
+ * 0: Disabled,
+ * 2: Enabled Trace active: TraceHub is enabled and trace is active, blocks s0ix,
+ * 4: Enabled Trace ready: TraceHub is enabled and allowed S0ix,
+ * 6: Enabled Trace power off: TraceHub is powergated, provide setting close to functional
+ *    low power state,
+ * 7: User needs to configure Advanced Debug Settings manually. (only applicable for devices
+ *    with BIOS Setup Menu option present.
+ */
+enum platform_hw_debug_option {
+	HW_DEBUG_DISABLE = 0,
+	HW_DEBUG_TRACEHUB_ACTIVE = BIT(1),
+	HW_DEBUG_TRACEHUB_READY = BIT(2),
+	HW_DEBUG_TRACEHUB_POWEROFF = BIT(2) | BIT(1),
+};
+
 /*
  * As per definition from FSP header:
  * - [0] for IA
@@ -301,12 +345,21 @@ struct soc_intel_pantherlake_config {
 	bool cep_enable[NUM_VR_DOMAINS];
 
 	/*
-	 * VR Fast Vmode I_TRIP threshold.
+	 * Fast Vmode I_TRIP Thresholds for VR Domains
+	 *
+	 * This two-dimensional array represents the Fast Vmode I_TRIP thresholds
+	 * for various Voltage Regulator (VR) domains across different power limit
+	 * configurations in Panther Lake SoCs.
+	 *
+	 * The Fast Vmode I_TRIP threshold is used to override the default current
+	 * threshold settings, ensuring optimal power management by adapting to
+	 * specific VR domain requirements under different power limit scenarios.
+	 *
 	 * 0-255A in 1/4 A units. Example: 400 = 100A
 	 * This setting overrides the default value set by FSPs when Fast VMode
 	 * is enabled.
 	 */
-	uint16_t fast_vmode_i_trip[NUM_VR_DOMAINS];
+	uint16_t fast_vmode_i_trip[PTL_POWER_LIMITS_COUNT][NUM_VR_DOMAINS];
 
 	/*
 	 * Power state current threshold 1.
@@ -332,6 +385,23 @@ struct soc_intel_pantherlake_config {
 	 */
 	uint16_t ps_cur_3_threshold[NUM_VR_DOMAINS];
 
+	/*
+	 * Thermal Design Current (TDC) settings for various SKUs.
+	 *
+	 * This multidimensional array stores the Thermal Design Current (TDC)
+	 * values for different power limit configurations across multiple SKUs
+	 * and Voltage Regulator (VR) domains. TDC values indicate the maximum
+	 * allowable current for a given thermal configuration, which helps in
+	 * managing thermal constraints for each VR domain under specific power
+	 * limit scenarios.
+	 *
+	 * Each entry in the array is indexed by SKU and VR domain, providing
+	 * tailored TDC values for specific power management requirements.
+	 *
+	 * The TDC unit is defined 1/8A increments.
+	 */
+	uint16_t thermal_design_current[MAX_PTL_SKUS][NUM_VR_DOMAINS];
+
 	/*
 	 * SerialIO device mode selection:
 	 * PchSerialIoDisabled,
@@ -514,6 +584,19 @@ struct soc_intel_pantherlake_config {
 
 	uint16_t max_dram_speed_mts;
 
+	/*
+	 * Touch Host Controller Mode
+	 * Switch between Intel THC protocol and Industry standard HID protocols.
+	 * 0x0:Thc, 0x1:HID over SPI, 0x2:HID over I2C
+	 */
+	uint8_t thc_mode[NUM_THC];
+
+	/*
+	 * Touch Host Controller Wake On Touch
+	 * Based on this setting vGPIO for given THC will be in native mode, and additional _CRS
+	 * for wake will be exposed in ACPI
+	 */
+	bool thc_wake_on_touch[NUM_THC];
 };
 
 typedef struct soc_intel_pantherlake_config config_t;
