@@ -6,12 +6,21 @@
 #include <soc/gpio_defs.h>
 #include <intelblocks/gpio.h>
 
+#if CONFIG(SOC_INTEL_WILDCATLAKE)
+#define CROS_GPIO_NAME           "INTC10EC"
+#define CROS_GPIO_DEVICE0_NAME   "INTC10EC:00"
+#define CROS_GPIO_DEVICE1_NAME   "INTC10EC:01"
+#define CROS_GPIO_DEVICE2_NAME   "INTC10EC:02"
+#define CROS_GPIO_DEVICE3_NAME   "INTC10EC:03"
+#define CROS_GPIO_DEVICE4_NAME   "INTC10EC:04"
+#else
 #define CROS_GPIO_NAME           "INTC10BC"
 #define CROS_GPIO_DEVICE0_NAME   "INTC10BC:00"
 #define CROS_GPIO_DEVICE1_NAME   "INTC10BC:01"
 #define CROS_GPIO_DEVICE2_NAME   "INTC10BC:02"
 #define CROS_GPIO_DEVICE3_NAME   "INTC10BC:03"
 #define CROS_GPIO_DEVICE4_NAME   "INTC10BC:04"
+#endif
 
 #define ACPI_GPIO_CID "INTC105F"
 #define ACPI_GPIO_HID CROS_GPIO_NAME
