@@ -33,6 +33,12 @@
 #define  PCI_DEV_IPU		_PCI_DEV(IPU, 0)
 
 #define PCI_DEV_SLOT_PCIE_2	0x06
+#if CONFIG(SOC_INTEL_WILDCATLAKE)
+#define  PCI_DEVFN_PCIE5	_PCI_DEVFN(PCIE_2, 0)
+#define  PCI_DEVFN_PCIE6	_PCI_DEVFN(PCIE_2, 1)
+#define  PCI_DEV_PCIE5		_PCI_DEV(PCIE_2, 0)
+#define  PCI_DEV_PCIE6		_PCI_DEV(PCIE_2, 1)
+#else
 #define  PCI_DEVFN_PCIE9	_PCI_DEVFN(PCIE_2, 0)
 #define  PCI_DEVFN_PCIE10	_PCI_DEVFN(PCIE_2, 1)
 #define  PCI_DEVFN_PCIE11	_PCI_DEVFN(PCIE_2, 2)
@@ -41,6 +47,7 @@
 #define  PCI_DEV_PCIE10		_PCI_DEV(PCIE_2, 1)
 #define  PCI_DEV_PCIE11		_PCI_DEV(PCIE_2, 2)
 #define  PCI_DEV_PCIE12		_PCI_DEV(PCIE_2, 3)
+#endif
 
 #define PCI_DEV_SLOT_TBT	0x07
 #define PCI_DEVFN_TBT(x)	_PCI_DEVFN(TBT, (x))
@@ -48,11 +55,11 @@
 #define  PCI_DEVFN_TBT0		_PCI_DEVFN(TBT, 0)
 #define  PCI_DEVFN_TBT1		_PCI_DEVFN(TBT, 1)
 #define  PCI_DEVFN_TBT2		_PCI_DEVFN(TBT, 2)
-#define  PCI_DEVFN_TBT3         _PCI_DEVFN(TBT, 3)
+#define  PCI_DEVFN_TBT3		_PCI_DEVFN(TBT, 3)
 #define  PCI_DEV_TBT0		_PCI_DEV(TBT, 0)
 #define  PCI_DEV_TBT1		_PCI_DEV(TBT, 1)
 #define  PCI_DEV_TBT2		_PCI_DEV(TBT, 2)
-#define  PCI_DEV_TBT3           _PCI_DEV(TBT, 3)
+#define  PCI_DEV_TBT3		_PCI_DEV(TBT, 3)
 
 #define PCI_DEV_SLOT_TELEMETRY	0x0a
 #define  PCI_DEVFN_TELEMETRY	_PCI_DEVFN(TELEMETRY, 0)
@@ -79,6 +86,10 @@
 #define  PCI_DEV_TCSS_DMA0	_PCI_DEV(TCSS, 2)
 #define  PCI_DEV_TCSS_DMA1	_PCI_DEV(TCSS, 3)
 
+#define PCI_DEV_SLOT_VMD	0x0e
+#define  PCI_DEVFN_VMD		_PCI_DEVFN(VMD, 0)
+#define  PCI_DEV_VMD		_PCI_DEV(VMD, 0)
+
 #define PCI_DEV_SLOT_THC	0x10
 #define  PCI_DEVFN_THC0		_PCI_DEVFN(THC, 0)
 #define  PCI_DEVFN_THC1		_PCI_DEVFN(THC, 1)
@@ -139,7 +150,7 @@
 #define  PCI_DEV_CSE_3		_PCI_DEV(CSE, 4)
 #define  PCI_DEV_CSE_4		_PCI_DEV(CSE, 5)
 
-#if CONFIG(SOC_INTEL_PANTHERLAKE_U_H)
+#if (CONFIG(SOC_INTEL_PANTHERLAKE_U_H) || CONFIG(SOC_INTEL_WILDCATLAKE))
 #define PCI_DEV_SLOT_UFS	0x17
 #define  PCI_DEVFN_UFS		_PCI_DEVFN(UFS, 0)
 #define  PCI_DEV_UFS		_PCI_DEV(UFS, 0)
@@ -166,19 +177,23 @@
 #define  PCI_DEVFN_PCIE2	_PCI_DEVFN(PCIE_1, 1)
 #define  PCI_DEVFN_PCIE3	_PCI_DEVFN(PCIE_1, 2)
 #define  PCI_DEVFN_PCIE4	_PCI_DEVFN(PCIE_1, 3)
+#if CONFIG(SOC_INTEL_PANTHERLAKE)
 #define  PCI_DEVFN_PCIE5	_PCI_DEVFN(PCIE_1, 4)
 #define  PCI_DEVFN_PCIE6	_PCI_DEVFN(PCIE_1, 5)
 #define  PCI_DEVFN_PCIE7	_PCI_DEVFN(PCIE_1, 6)
 #define  PCI_DEVFN_PCIE8	_PCI_DEVFN(PCIE_1, 7)
+#endif
 
 #define  PCI_DEV_PCIE1		_PCI_DEV(PCIE_1, 0)
 #define  PCI_DEV_PCIE2		_PCI_DEV(PCIE_1, 1)
 #define  PCI_DEV_PCIE3		_PCI_DEV(PCIE_1, 2)
 #define  PCI_DEV_PCIE4		_PCI_DEV(PCIE_1, 3)
+#if CONFIG(SOC_INTEL_PANTHERLAKE)
 #define  PCI_DEV_PCIE5		_PCI_DEV(PCIE_1, 4)
 #define  PCI_DEV_PCIE6		_PCI_DEV(PCIE_1, 5)
 #define  PCI_DEV_PCIE7		_PCI_DEV(PCIE_1, 6)
 #define  PCI_DEV_PCIE8		_PCI_DEV(PCIE_1, 7)
+#endif
 
 #define PCI_DEV_SLOT_SIO2	0x1e
 #define  PCI_DEVFN_UART0	_PCI_DEVFN(SIO2, 0)
@@ -232,7 +247,6 @@
 #define PCH_DEV_SPI		PCI_DEV_SPI
 #define PCH_DEV_LPC		PCI_DEV_ESPI
 #define PCH_DEV_P2SB		PCI_DEV_P2SB
-#define PCI_DEV_IOE_P2SB	PCI_DEV_P2SB2
 #define PCH_DEV_SMBUS		PCI_DEV_SMBUS
 #define PCH_DEV_XHCI		PCI_DEV_XHCI
 #define PCH_DEVFN_XHCI		PCI_DEVFN_XHCI
