@@ -19,11 +19,8 @@ int retimer_get_index_for_typec(uint8_t typec_port)
 	};
 
 	for (uint8_t i = 0; i < MAX_TYPE_C_PORTS; i++) {
-		if (i == typec_port) {
-			printk(BIOS_ERR, "USB Type-C %d mapped to EC port %d\n", typec_port,
-					ec_port);
+		if (i == typec_port)
 			return ec_port;
-		}
 
 		if (is_dev_enabled(tcss_port_arr[i]))
 			ec_port++;
