@@ -22,6 +22,8 @@ enum {
 	PMIC_VCORE_ELR0		= 0x152c,
 	PMIC_VGPU11_DBG0	= 0x15a6,
 	PMIC_VGPU11_ELR0	= 0x15b4,
+	PMIC_VMODEM_DBG0	= 0x16a6,
+	PMIC_VMODEM_ELR0	= 0x16ae,
 	PMIC_VS2_VOTER		= 0x18aa,
 	PMIC_VS2_VOTER_CFG	= 0x18b0,
 	PMIC_VS2_ELR0		= 0x18b4,
@@ -30,12 +32,14 @@ enum {
 	PMIC_VPA_DBG0		= 0x1914,
 	PMIC_BUCK_VPA_DLC_CON0	= 0x1918,
 	PMIC_BUCK_VPA_DLC_CON1	= 0x191a,
-	PMIC_VSIM1_CON0		= 0x1cd0,
 	PMIC_VSRAM_PROC1_ELR	= 0x1b44,
 	PMIC_VSRAM_PROC2_ELR	= 0x1b46,
+	PMIC_VSRAM_MD_ELR	= 0x1b4a,
+	PMIC_VSIM1_CON0		= 0x1cd0,
 	PMIC_VM18_CON0		= 0x1d88,
 	PMIC_VSRAM_PROC1_VOSEL1	= 0x1e90,
 	PMIC_VSRAM_PROC2_VOSEL1	= 0x1eb0,
+	PMIC_VSRAM_MD_VOSEL1	= 0x1f36,
 	PMIC_VSIM1_ANA_CON0	= 0x1fa2,
 	PMIC_VM18_ANA_CON0	= 0x2020,
 };
@@ -62,6 +66,8 @@ enum {
 	MT6359P_PA,
 	MT6359P_SIM1,
 	MT6359P_VM18,
+	MT6359P_VMODEM,
+	MT6359P_VSRAM_MD,
 	MT6359P_MAX,
 };
 
@@ -88,6 +94,7 @@ void mt6359p_enable_vpa(bool enable);
 void mt6359p_enable_vsim1(bool enable);
 void mt6359p_enable_vm18(bool enable);
 void mt6359p_init_pmif_arb(void);
+u32 mt6359p_read_field(u32 reg, u32 mask, u32 shift);
 void mt6359p_write_field(u32 reg, u32 val, u32 mask, u32 shift);
 void mt6359p_init_setting(void);
 void mt6359p_lp_setting(void);
