@@ -90,10 +90,10 @@ enum {
 #define MT6315_DEFAULT_VALUE_READ 0x15
 
 extern const struct spmi_device spmi_dev[];
-extern const size_t spmi_dev_cnt;
 
 int pmif_spmi_init(struct pmif *arb);
 int spmi_config_master(void);
+size_t spmi_dev_cnt(void);
 void pmif_spmi_iocfg(void);
 void pmif_spmi_config(struct pmif *arb);
 #endif /* __SOC_MEDIATEK_PMIF_SPMI_H__ */
