@@ -15,7 +15,7 @@ DEFINE_BITFIELD(SCP_SLEEP_REQ_SEL, 10, 9)
 
 void pmif_spmi_set_lp_mode(void)
 {
-	SET32_BITFIELDS((void *)(PMIF_BASE + SLEEP_PROT_CTRL),
+	SET32_BITFIELDS((void *)(PMIF_SPMI_BASE + SLEEP_PROT_CTRL),
 			SPM_SLEEP_REQ_SEL, 0,
 			SCP_SLEEP_REQ_SEL, 0);
 }
