@@ -1,9 +1,8 @@
-/* SPDX-License-Identifier: GPL-2.0-only */
+/* SPDX-License-Identifier: GPL-2.0-only OR MIT */
 
 #include <console/console.h>
 #include <device/mmio.h>
 #include <delay.h>
-#include <stddef.h>
 #include <timer.h>
 
 #include <soc/addressmap.h>
@@ -755,7 +754,7 @@ void mt_pll_init(void)
 	 * TOP CLKMUX -- DO NOT CHANGE WITHOUT ADJUSTING <soc/pll.h> CONSTANTS!
 	 */
 	for (i = 0; i < ARRAY_SIZE(mux_sels); i++)
-		mux_set_sel(&muxes[mux_sels[i].id], mux_sels[i].sel);
+		pll_mux_set_sel(&muxes[mux_sels[i].id], mux_sels[i].sel);
 
 	/* switch sram control to bypass mode for PCIE_MAC_P0 */
 	setbits32(&mtk_spm->ap_mdsrc_req, 0x1);
@@ -827,9 +826,9 @@ void mt_pll_set_tvd_pll1_freq(u32 freq)
 	udelay(PLL_EN_DELAY);
 }
 
-void edp_mux_set_sel(u32 sel)
+void mt_pll_edp_mux_set_sel(u32 sel)
 {
-	mux_set_sel(&muxes[TOP_EDP_SEL], sel);
+	pll_mux_set_sel(&muxes[TOP_EDP_SEL], sel);
 }
 
 u32 mt_fmeter_get_freq_khz(enum fmeter_type type, u32 id)
