@@ -1,21 +1,8 @@
-/*
- * Copyright 2014 Google Inc.
- * Copyright (c) 2013-2015, NVIDIA CORPORATION.  All rights reserved.
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms and conditions of the GNU General Public License,
- * version 2, as published by the Free Software Foundation.
- *
- * This program is distributed in the hope it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
- */
+/* SPDX-License-Identifier: GPL-2.0-only */
 
 #ifndef __NVIDIA_TEGRA210_SPI_H__
 #define __NVIDIA_TEGRA210_SPI_H__
 
-#include <compiler.h>
 #include <soc/dma.h>
 #include <spi-generic.h>
 #include <stddef.h>
