@@ -43,7 +43,7 @@ struct qclib_cb_if_table_entry {
 };
 
 /* GA_BMASK_VALUES (global_attributes bit mask values) */
-#define QCLIB_GA_ENABLE_UART_LOGGING   0x00000001
+#define QCLIB_GA_ENABLE_UART_LOGGING   BIT(0)
 #define QCLIB_GA_FORCE_COLD_REBOOT BIT(3)
 #define QCLIB_GA_DDR_FMAX_LIMIT_HYNIX8GB BIT(5)
 
