@@ -13,7 +13,6 @@ static void soc_read_resources(struct device *dev)
 
 static void soc_init(struct device *dev)
 {
-
 }
 
 static struct device_operations soc_ops = {
@@ -27,6 +26,6 @@ static void enable_soc_dev(struct device *dev)
 }
 
 struct chip_operations soc_qualcomm_qcs405_ops = {
-	CHIP_NAME("SOC Qualcomm QCS405")
+	.name = "SOC Qualcomm QCS405",
 	.enable_dev = enable_soc_dev,
 };
