@@ -16,9 +16,7 @@
 #include <device/pci_ops.h>
 #include <console/console.h>
 #include <device/pci_ids.h>
-#include <device/pci_def.h>
 #include <elog.h>
-#include <halt.h>
 #include <option.h>
 #include <southbridge/intel/common/me.h>
 
