@@ -38,12 +38,11 @@ static void pch_enable_ioapic(struct device *dev)
 	/* affirm full set of redirection table entries ("write once") */
 	/* PCH-LP has 40 redirection entries */
 	if (pch_is_lp())
-		ioapic_set_max_vectors(VIO_APIC_VADDR, 40);
+		ioapic_set_max_vectors(IO_APIC_ADDR, 40);
 	else
-		ioapic_lock_max_vectors(VIO_APIC_VADDR);
-
-	setup_ioapic(VIO_APIC_VADDR, 0x02);
+		ioapic_lock_max_vectors(IO_APIC_ADDR);
 
+	register_new_ioapic_gsi0(IO_APIC_ADDR);
 }
 
 static void pch_enable_serial_irqs(struct device *dev)
@@ -835,6 +834,11 @@ static const unsigned short pci_device_ids[] = {
 	PCI_DID_INTEL_LPT_LP_PREMIUM,
 	PCI_DID_INTEL_LPT_LP_MAINSTREAM,
 	PCI_DID_INTEL_LPT_LP_VALUE,
+	PCI_DID_INTEL_LPT_MOBILE_SAMPLE_9,
+	PCI_DID_INTEL_LPT_DESKTOP_SAMPLE_9,
+	PCI_DID_INTEL_LPT_HM97,
+	PCI_DID_INTEL_LPT_Z97,
+	PCI_DID_INTEL_LPT_H97,
 	0
 };
 
