@@ -25,6 +25,6 @@ static void enable_dev(struct device *dev)
 }
 
 struct chip_operations superio_nsc_pc87384_ops = {
-	CHIP_NAME("NSC PC87384 Super I/O")
+	.name = "NSC PC87384 Super I/O",
 	.enable_dev = enable_dev,
 };
