@@ -46,6 +46,6 @@ static void enable_dev(struct device *dev)
 }
 
 struct chip_operations superio_smsc_fdc37n972_ops = {
-	CHIP_NAME("SMSC FDC37N972 Super I/O")
+	.name = "SMSC FDC37N972 Super I/O",
 	.enable_dev = enable_dev,
 };
