@@ -1,21 +1,29 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
 #include <acpi/acpi.h>
-#include <amdblocks/acpi.h>
 #include <device/device.h>
+
 #include "../opensil.h"
 
-void add_opensil_memmap(struct device *dev, unsigned long *idx)
+void opensil_get_hole_info(uint32_t *n_holes, uint64_t *top_of_mem, void **hole_info)
+{
+	*n_holes = 0;
+	*top_of_mem = 0xc0000000;
+	printk(BIOS_NOTICE, "openSIL stub: %s\n", __func__);
+}
+
+const char *opensil_get_hole_info_type(uint32_t type)
+{
+	printk(BIOS_NOTICE, "openSIL stub: %s\n", __func__);
+	return "";
+}
+
+void opensil_fill_fadt(acpi_fadt_t *fadt)
 {
 	printk(BIOS_NOTICE, "openSIL stub: %s\n", __func__);
 }
 
-void opensil_fill_fadt_io_ports(acpi_fadt_t *fadt)
-{
-	printk(BIOS_NOTICE, "openSIL stub: %s\n", __func__);
-}
-
-unsigned long acpi_add_opensil_tables(unsigned long current, acpi_rsdp_t *rsdp)
+unsigned long add_opensil_acpi_table(unsigned long current, acpi_rsdp_t *rsdp)
 {
 	printk(BIOS_NOTICE, "openSIL stub: %s\n", __func__);
 	return current;
