@@ -382,10 +382,15 @@ amd_bios_entry amd_bios_table[] = {
 #define BUFF_TO_RUN_MODE(ctx, ptr, mode) RUN_OFFSET_MODE((ctx), ((char *)(ptr) - (ctx).rom), \
 		(ctx).address_mode < (mode) ? (ctx).address_mode : (mode))
 #define BUFF_ROOM(ctx) ((ctx).rom_size - (ctx).current)
-/* Only set the address mode in entry if the table is mode 2. */
+/* AMD PSP Spec: Only set the address mode in entry if the table is mode 2 or 3. */
+/* For address mode 3, it is not be used in any SOC family yet.
+   For address mode 1, we can use it to store and transfer the address mode.
+   It can reduce the complexity. */
 #define SET_ADDR_MODE(table, mode) \
-		((table)->header.additional_info_fields.address_mode ==	\
-		AMD_ADDR_REL_TAB ? (mode) : 0)
+		((table)->header.additional_info_fields.address_mode == AMD_ADDR_REL_TAB ||  \
+		 (table)->header.additional_info_fields.address_mode == AMD_ADDR_REL_BIOS || \
+		 (table)->header.additional_info_fields.address_mode == AMD_ADDR_REL_SLOT    \
+		 ? (mode) : 0)
 #define SET_ADDR_MODE_BY_TABLE(table) \
 		SET_ADDR_MODE((table), (table)->header.additional_info_fields.address_mode)
 
@@ -626,6 +631,7 @@ static void fill_psp_directory_to_efs(embedded_firmware *amd_romsig, void *pspdi
 	case PLATFORM_LUCIENNE:
 	case PLATFORM_RENOIR:
 	case PLATFORM_GENOA:
+	case PLATFORM_FAEGAN:
 	default:
 		/* for combo, it is also combo_psp_directory */
 		amd_romsig->new_psp_directory =
@@ -657,6 +663,7 @@ static void fill_bios_directory_to_efs(embedded_firmware *amd_romsig, void *bios
 	case PLATFORM_MENDOCINO:
 	case PLATFORM_PHOENIX:
 	case PLATFORM_GLINDA:
+	case PLATFORM_FAEGAN:
 		break;
 	case PLATFORM_CARRIZO:
 	case PLATFORM_STONEYRIDGE:
@@ -699,6 +706,9 @@ static uint32_t get_psp_id(enum platform soc_id)
 	case PLATFORM_GENOA:
 		psp_id = 0xBC0C0111;
 		break;
+	case PLATFORM_FAEGAN:
+		psp_id = 0xbc0e1000;
+		break;
 	case PLATFORM_CARRIZO:
 	default:
 		psp_id = 0;
@@ -1157,20 +1167,20 @@ static void *new_bios_dir(context *ctx, bool multi, uint32_t cookie)
 	return ptr;
 }
 
-static int locate_bdt2_bios(bios_directory_table *level2,
+static int locate_bdt_bios(bios_directory_table *level,
 					uint64_t *source, uint32_t *size)
 {
 	uint32_t i;
 
 	*source = 0;
 	*size = 0;
-	if (!level2)
+	if (!level)
 		return 0;
 
-	for (i = 0 ; i < level2->header.num_entries ; i++) {
-		if (level2->entries[i].type == AMD_BIOS_BIN) {
-			*source = level2->entries[i].source;
-			*size = level2->entries[i].size;
+	for (i = 0 ; i < level->header.num_entries ; i++) {
+		if (level->entries[i].type == AMD_BIOS_BIN) {
+			*source = level->entries[i].source;
+			*size = level->entries[i].size;
 			return 1;
 		}
 	}
@@ -1400,28 +1410,15 @@ static void integrate_bios_firmwares(context *ctx,
 			biosdir->entries[count].address_mode = SET_ADDR_MODE_BY_TABLE(biosdir);
 			break;
 		case AMD_BIOS_APOB_NV:
-			if (fw_table[i].src) {
-				/* If source is given, use that and its size */
-				biosdir->entries[count].source = fw_table[i].src;
-				biosdir->entries[count].address_mode =
-						SET_ADDR_MODE(biosdir, AMD_ADDR_REL_BIOS);
-				biosdir->entries[count].size = fw_table[i].size;
-			} else {
-				/* Else reserve size bytes within amdfw.rom */
-				adjust_current_pointer(ctx, 0, ERASE_ALIGNMENT);
-				biosdir->entries[count].source = RUN_CURRENT(*ctx);
-				biosdir->entries[count].address_mode =
-						SET_ADDR_MODE(biosdir, AMD_ADDR_REL_BIOS);
-				biosdir->entries[count].size = ALIGN_UP(
-						fw_table[i].size, ERASE_ALIGNMENT);
-				memset(BUFF_CURRENT(*ctx), 0xff,
-						biosdir->entries[count].size);
-				adjust_current_pointer(ctx, biosdir->entries[count].size, 1);
-			}
+			biosdir->entries[count].source = fw_table[i].src;
+			biosdir->entries[count].address_mode =
+					SET_ADDR_MODE(biosdir, AMD_ADDR_REL_BIOS);
+			biosdir->entries[count].size = fw_table[i].size;
 			break;
 		case AMD_BIOS_BIN:
 			/* Don't make a 2nd copy, point to the same one */
-			if (level == BDT_LVL1 && locate_bdt2_bios(ctx->biosdir2, &source, &size)) {
+			if ((level == BDT_LVL1 && locate_bdt_bios(ctx->biosdir2, &source, &size)) ||
+				(level == BDT_LVL2 && locate_bdt_bios(ctx->biosdir, &source, &size))) {
 				biosdir->entries[count].source = source;
 				biosdir->entries[count].address_mode =
 						SET_ADDR_MODE(biosdir, AMD_ADDR_REL_BIOS);
@@ -1429,7 +1426,7 @@ static void integrate_bios_firmwares(context *ctx,
 				break;
 			}
 
-			/* level 2, or level 1 and no copy found in level 2 */
+			/* Level 2 and no copy found in level 1, or level 1 and no copy found in level 2 */
 			biosdir->entries[count].source = fw_table[i].src;
 			biosdir->entries[count].address_mode =
 						SET_ADDR_MODE(biosdir, AMD_ADDR_REL_BIOS);
@@ -1447,9 +1444,9 @@ static void integrate_bios_firmwares(context *ctx,
 			}
 
 			biosdir->entries[count].source =
-				RUN_CURRENT_MODE(*ctx, AMD_ADDR_REL_BIOS);
+				RUN_CURRENT(*ctx);
 			biosdir->entries[count].address_mode =
-				SET_ADDR_MODE(biosdir, AMD_ADDR_REL_BIOS);
+				SET_ADDR_MODE_BY_TABLE(biosdir);
 
 			adjust_current_pointer(ctx, bytes, 0x100U);
 			break;
@@ -1551,6 +1548,7 @@ static int set_efs_table(uint8_t soc_id, amd_cb_config *cb_config,
 	case PLATFORM_PHOENIX:
 	case PLATFORM_GLINDA:
 	case PLATFORM_GENOA:
+	case PLATFORM_FAEGAN:
 		amd_romsig->spi_readmode_f17_mod_30_3f = cb_config->efs_spi_readmode;
 		amd_romsig->spi_fastspeed_f17_mod_30_3f = cb_config->efs_spi_speed;
 		switch (cb_config->efs_spi_micron_flag) {
@@ -1609,6 +1607,7 @@ static bool is_initial_alignment_required(enum platform soc_id)
 	case PLATFORM_MENDOCINO:
 	case PLATFORM_PHOENIX:
 	case PLATFORM_GLINDA:
+	case PLATFORM_FAEGAN:
 		return false;
 	default:
 		return true;
@@ -1623,7 +1622,6 @@ static bool needs_new_combo_layout(enum platform soc_id)
 int main(int argc, char **argv)
 {
 	int retval = 0;
-	int combo_index = 0;
 	int targetfd;
 	context ctx = { 0 };
 	uint32_t romsig_offset;
@@ -1714,17 +1712,17 @@ int main(int argc, char **argv)
 			ctx.bhd_combo_dir = new_combo_dir(&ctx, BHD2_COOKIE);
 	}
 
-	combo_index = 0;
+	ctx.combo_index = 0;
 	if (cb_config.config)
 		cb_config.combo_config[0] = cb_config.config;
 
 	do {
 		if (cb_config.use_combo && cb_config.debug)
-			printf("Processing %dth combo entry\n", combo_index);
+			printf("Processing %dth combo entry\n", ctx.combo_index);
 
 		/* The pspdir level 1 is special. For new combo layout, all the combo entries
 		   share one pspdir L1. It should not be cleared at each iteration. */
-		if (!cb_config.combo_new_rab || combo_index == 0) {
+		if (!cb_config.combo_new_rab || ctx.combo_index == 0) {
 			ctx.pspdir = NULL;
 			ctx.pspdir_bak = NULL;
 		}
@@ -1741,14 +1739,14 @@ int main(int argc, char **argv)
 		 *  and make it clear this will not affect non-combo
 		 *  case.
 		 */
-		if (cb_config.use_combo && combo_index > 0) {
+		if (cb_config.use_combo && ctx.combo_index > 0) {
 			/* Restore the table as clean data. */
 			memcpy(amd_psp_fw_table, ctx.amd_psp_fw_table_clean,
 				sizeof(amd_psp_fw_table));
 			memcpy(amd_bios_table, ctx.amd_bios_table_clean,
 				sizeof(amd_bios_table));
-			assert_fw_entry(combo_index, MAX_COMBO_ENTRIES, &ctx);
-			open_process_config(cb_config.combo_config[combo_index], &cb_config);
+			assert_fw_entry(ctx.combo_index, MAX_COMBO_ENTRIES, &ctx);
+			open_process_config(cb_config.combo_config[ctx.combo_index], &cb_config);
 
 			/* In most cases, the address modes are same. */
 			if (cb_config.need_ish)
@@ -1758,32 +1756,28 @@ int main(int argc, char **argv)
 			else
 				ctx.address_mode = AMD_ADDR_PHYSICAL;
 
-			register_apcb_combo(&cb_config, combo_index, &ctx);
+			register_apcb_combo(&cb_config, ctx.combo_index, &ctx);
 		}
 
 		if (cb_config.multi_level) {
-			/* Do 2nd PSP directory followed by 1st */
-			integrate_psp_firmwares(&ctx,
-						amd_psp_fw_table, PSPL2_COOKIE, &cb_config);
-			if (cb_config.recovery_ab && !cb_config.recovery_ab_single_copy) {
-				/* Create a copy of PSP Directory 2 in the backup slot B.
-				   Related biosdir2_b copy will be created later. */
-				integrate_psp_firmwares(&ctx,
-						amd_psp_fw_table, PSPL2_COOKIE, &cb_config);
-			} else {
-				/*
-				 * Either the platform is using only
-				 * one slot or B is same as above
-				 * directories for A. Skip creating
-				 * pspdir2_b here to save flash space.
-				 * Related biosdir2_b will be skipped
-				 * automatically.
-				 */
-				ctx.pspdir2_b = NULL; /* More explicitly */
-			}
-			if (!cb_config.combo_new_rab || combo_index == 0)
+			/* PSP L1 */
+			if (!cb_config.combo_new_rab || ctx.combo_index == 0)
 				integrate_psp_firmwares(&ctx,
 					amd_psp_fw_table, PSP_COOKIE, &cb_config);
+			/* PSP L2 & BIOS L2 (if AB recovery) */
+			integrate_psp_firmwares(&ctx,
+						amd_psp_fw_table, PSPL2_COOKIE, &cb_config);
+			if (cb_config.recovery_ab) {
+				integrate_bios_firmwares(&ctx,
+						amd_bios_table, BHDL2_COOKIE, &cb_config);
+				if (!cb_config.recovery_ab_single_copy) {
+					integrate_psp_firmwares(&ctx,
+						amd_psp_fw_table, PSPL2_COOKIE, &cb_config);
+					integrate_bios_firmwares(&ctx,
+						amd_bios_table, BHDL2_COOKIE, &cb_config);
+				}
+				integrate_bios_levels(&ctx, &cb_config);
+			}
 			integrate_psp_levels(&ctx, &cb_config);
 		} else {
 			/* flat: PSP 1 cookie and no pointer to 2nd table */
@@ -1791,35 +1785,26 @@ int main(int argc, char **argv)
 					amd_psp_fw_table, PSP_COOKIE, &cb_config);
 		}
 
-		if (!cb_config.use_combo || (cb_config.combo_new_rab && combo_index == 0)) {
+		if (!cb_config.use_combo || (cb_config.combo_new_rab && ctx.combo_index == 0)) {
 			/* For new combo layout, there is only 1 PSP level 1 directory. */
 			fill_psp_directory_to_efs(ctx.amd_romsig_ptr, ctx.pspdir, &ctx, &cb_config);
 			fill_psp_bak_directory_to_efs(ctx.amd_romsig_ptr, ctx.pspdir_bak, &ctx, &cb_config);
 		} else if (cb_config.use_combo && !cb_config.combo_new_rab) {
 			fill_psp_directory_to_efs(ctx.amd_romsig_ptr, ctx.psp_combo_dir, &ctx, &cb_config);
-			add_combo_entry(ctx.psp_combo_dir, ctx.pspdir, combo_index, &ctx, &cb_config);
+			add_combo_entry(ctx.psp_combo_dir, ctx.pspdir, ctx.combo_index, &ctx, &cb_config);
 		}
 
-		if (have_bios_tables(amd_bios_table)) {
+		if (have_bios_tables(amd_bios_table) && !cb_config.recovery_ab) {
 			if (cb_config.multi_level) {
-				/* Do 2nd level BIOS directory followed by 1st */
+				integrate_bios_firmwares(&ctx,
+						amd_bios_table, BHD_COOKIE, &cb_config);
 				integrate_bios_firmwares(&ctx,
 						amd_bios_table, BHDL2_COOKIE, &cb_config);
-				if (cb_config.recovery_ab) {
-					if (ctx.pspdir2_b != NULL) {
-						integrate_bios_firmwares(&ctx,
-								amd_bios_table, BHDL2_COOKIE,
-								&cb_config);
-					}
-				} else {
-					integrate_bios_firmwares(&ctx,
-							amd_bios_table, BHD_COOKIE, &cb_config);
-				}
 				integrate_bios_levels(&ctx, &cb_config);
 			} else {
 				/* flat: BHD1 cookie and no pointer to 2nd table */
 				integrate_bios_firmwares(&ctx,
-							amd_bios_table, BHD_COOKIE, &cb_config);
+						amd_bios_table, BHD_COOKIE, &cb_config);
 			}
 			if (!cb_config.use_combo) {
 				fill_bios_directory_to_efs(ctx.amd_romsig_ptr, ctx.biosdir,
@@ -1830,13 +1815,13 @@ int main(int argc, char **argv)
 				 */
 				fill_bios_directory_to_efs(ctx.amd_romsig_ptr, ctx.bhd_combo_dir,
 					&ctx, &cb_config);
-				add_combo_entry(ctx.bhd_combo_dir, ctx.biosdir, combo_index, &ctx, &cb_config);
+				add_combo_entry(ctx.bhd_combo_dir, ctx.biosdir, ctx.combo_index, &ctx, &cb_config);
 			}
 		}
 		if (cb_config.debug)
 			dump_image_addresses(&ctx);
-	} while (cb_config.use_combo && ++combo_index < MAX_COMBO_ENTRIES &&
-					cb_config.combo_config[combo_index] != NULL);
+	} while (cb_config.use_combo && ++ctx.combo_index < MAX_COMBO_ENTRIES &&
+					cb_config.combo_config[ctx.combo_index] != NULL);
 
 	targetfd = open(cb_config.output, O_RDWR | O_CREAT | O_TRUNC, 0666);
 	if (targetfd >= 0) {
