@@ -170,6 +170,7 @@ static void eventlog_print_type(const struct event_header *event)
 		{ELOG_TYPE_PSR_DATA_LOST, "PSR data lost"},
 		{ELOG_TYPE_FW_SPLASH_SCREEN, "Firmware Splash Screen"},
 		{ELOG_TYPE_FW_CSE_SYNC, "Firmware CSE sync"},
+		{ELOG_TYPE_LOW_BATTERY_INDICATOR, "Low Battery boot"},
 		{ELOG_TYPE_EOL, "End of log"},
 	};
 
@@ -318,8 +319,8 @@ static int eventlog_print_data(const struct event_header *event)
 		{ELOG_WAKE_SOURCE_GPIO, " GPIO #"},
 		{ELOG_WAKE_SOURCE_PME_TBT, "PME - Thunderbolt"},
 		{ELOG_WAKE_SOURCE_PME_TCSS_XHCI, "PME - TCSS XHCI"},
-		{ELOG_WAKE_SOURCE_PME_TCSS_XHCI, "PME - TCSS XDCI"},
-		{ELOG_WAKE_SOURCE_PME_TCSS_XHCI, "PME - TCSS DMA"},
+		{ELOG_WAKE_SOURCE_PME_TCSS_XDCI, "PME - TCSS XDCI"},
+		{ELOG_WAKE_SOURCE_PME_TCSS_DMA, "PME - TCSS DMA"},
 		{0, NULL},
 	};
 	static const struct valstr ec_event_types[] = {
@@ -491,6 +492,11 @@ static int eventlog_print_data(const struct event_header *event)
 		{0, NULL},
 	};
 
+	static const struct valstr low_battery_status[] = {
+		{ELOG_FW_ISSUE_SHUTDOWN, "Power Off"},
+		{0, NULL},
+	};
+
 	size_t elog_type_to_min_size[] = {
 		[ELOG_TYPE_LOG_CLEAR]		= sizeof(uint16_t),
 		[ELOG_TYPE_BOOT]		= sizeof(uint32_t),
@@ -513,6 +519,7 @@ static int eventlog_print_data(const struct event_header *event)
 		[ELOG_TYPE_PSR_DATA_BACKUP]	= sizeof(uint8_t),
 		[ELOG_TYPE_FW_SPLASH_SCREEN]	= sizeof(uint8_t),
 		[ELOG_TYPE_FW_CSE_SYNC]		= sizeof(uint8_t),
+		[ELOG_TYPE_LOW_BATTERY_INDICATOR]	= sizeof(uint8_t),
 		[0xff]				= 0,
 	};
 
@@ -684,6 +691,11 @@ static int eventlog_print_data(const struct event_header *event)
 		eventlog_printf("%s", val2str(*cse_event, cse_sync_path_types));
 		break;
 	}
+	case ELOG_TYPE_LOW_BATTERY_INDICATOR: {
+		const uint8_t *low_battery_event = event_get_data(event);
+		eventlog_printf("%s", val2str(*low_battery_event, low_battery_status));
+		break;
+	}
 	default:
 		break;
 	}
