@@ -13,7 +13,7 @@ main() {
   local prefix="$(echo "${board}" | tr a-z A-Z) TEST"
   # gzip has second-to-last 4 bytes in CRC32.
   local crc32="$(printf "${prefix}" | gzip -1 | tail -c 8 | head -c 4 | \
-		 hexdump -e '1/4 "%04u" ""' | tail -c 4)"
+		 od -An -vtu4 | tr -d '\n' | tail -c 4)"
 
   echo "${prefix}" "${crc32}"
 }
