@@ -74,6 +74,8 @@ const (
 	PlatformCZN
 	PlatformMDN
 	PlatformMTL
+	PlatformPHX
+	PlatformPTL
 	PlatformMax
 )
 
@@ -94,6 +96,8 @@ var platformNames = map[int]string{
 	PlatformCZN: "CZN",
 	PlatformMDN: "MDN",
 	PlatformMTL: "MTL",
+	PlatformPHX: "PHX",
+	PlatformPTL: "PTL",
 }
 
 var memTechMap = map[string]memTech{
